@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ TextPartTest::TextPartTest(QObject *parent)
 {
 }
 
-TextPartTest::~TextPartTest()
-{
-}
+TextPartTest::~TextPartTest() = default;
 
 void TextPartTest::shouldHaveDefaultValue()
 {
