@@ -1,42 +1,30 @@
 /*
  * This file is part of KMail.
- * Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+ * SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
  *
  * Parts based on KMail code by:
  * Various authors.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef MESSAGECOMPOSER_ATTACHMENTCONTROLLERBASE_H
-#define MESSAGECOMPOSER_ATTACHMENTCONTROLLERBASE_H
+#pragma once
+
+#include "messagecomposer_export.h"
+
+#include "editorwatcher.h"
 
 #include <QObject>
-
 #include <QUrl>
 
-#include <MessageCore/AttachmentPart>
-#include <MessageViewer/EditorWatcher>
-#include <KJob>
 #include <KService>
-#include "messagecomposer_export.h"
+#include <MessageCore/AttachmentPart>
 
 class KActionCollection;
 class QAction;
-
-namespace MessageComposer {
+class KJob;
+namespace MessageComposer
+{
 class AttachmentModel;
 /**
  * @brief The AttachmentControllerBase class
@@ -47,7 +35,7 @@ class MESSAGECOMPOSER_EXPORT AttachmentControllerBase : public QObject
 
 public:
     AttachmentControllerBase(MessageComposer::AttachmentModel *model, QWidget *wParent, KActionCollection *actionCollection);
-    ~AttachmentControllerBase();
+    ~AttachmentControllerBase() override;
 
     void createActions();
 
@@ -68,7 +56,8 @@ public Q_SLOTS:
     void showContextMenu();
     void openAttachment(const MessageCore::AttachmentPart::Ptr &part);
     void viewAttachment(const MessageCore::AttachmentPart::Ptr &part);
-    void editAttachment(MessageCore::AttachmentPart::Ptr part, MessageViewer::EditorWatcher::OpenWithOption option = MessageViewer::EditorWatcher::NoOpenWithDialog);
+    void editAttachment(MessageCore::AttachmentPart::Ptr part,
+                        MessageComposer::EditorWatcher::OpenWithOption option = MessageComposer::EditorWatcher::NoOpenWithDialog);
     void editAttachmentWith(const MessageCore::AttachmentPart::Ptr &part);
     void saveAttachmentAs(const MessageCore::AttachmentPart::Ptr &part);
     void attachmentProperties(const MessageCore::AttachmentPart::Ptr &part);
@@ -100,16 +89,13 @@ protected:
     void openWith(const KService::Ptr &offer = KService::Ptr());
 
 private:
-    void attachFiles(const QList<QUrl> &urls, const QString &encoding);
-    void attachDirectory(const QUrl &url);
-    void slotPutResult(KJob *job);
-    void slotOpenWithDialog();
-    void slotOpenWithAction(QAction *act);
+    MESSAGECOMPOSER_NO_EXPORT void attachDirectory(const QUrl &url);
+    MESSAGECOMPOSER_NO_EXPORT void slotPutResult(KJob *job);
+    MESSAGECOMPOSER_NO_EXPORT void slotOpenWithDialog();
+    MESSAGECOMPOSER_NO_EXPORT void slotOpenWithAction(QAction *act);
 
 private:
-    class Private;
-    Private *const d;
+    class AttachmentControllerBasePrivate;
+    std::unique_ptr<AttachmentControllerBasePrivate> const d;
 };
 } //
-
-#endif
