@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,10 +11,14 @@
 #include <KActionCollection>
 #include <KPIMTextEdit/RichTextComposerControler>
 
-#include <PimCommonAutoCorrection/AutoCorrection>
+#include "config-messagecomposer.h"
 #include <QStandardPaths>
 #include <QTest>
-
+#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
+#include <TextAutoCorrectionCore/AutoCorrection>
+#else
+#include <TextAutoCorrection/AutoCorrection>
+#endif
 RichTextComposerNgTest::RichTextComposerNgTest(QObject *parent)
     : QObject(parent)
 {
@@ -50,8 +54,13 @@ void RichTextComposerNgTest::shouldForceAutoCorrection()
     MessageComposer::RichTextComposerNg richtextComposerNg;
 
     richtextComposerNg.setPlainText(original);
-    PimCommonAutoCorrection::AutoCorrection autocorrection;
-    auto settings = new PimCommonAutoCorrection::AutoCorrectionSettings;
+#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
+    TextAutoCorrectionCore::AutoCorrection autocorrection;
+    auto settings = new TextAutoCorrectionCore::AutoCorrectionSettings;
+#else
+    TextAutoCorrection::AutoCorrection autocorrection;
+    auto settings = new TextAutoCorrection::AutoCorrectionSettings;
+#endif
     settings->setEnabledAutoCorrection(true);
     settings->setUppercaseFirstCharOfSentence(true);
     autocorrection.setAutoCorrectionSettings(settings);
@@ -89,8 +98,13 @@ void RichTextComposerNgTest::shouldForceAutoCorrectionWithSelection()
     cur.setPosition(selectionStart);
     cur.setPosition(selectionEnd, QTextCursor::KeepAnchor);
     richtextComposerNg.setTextCursor(cur);
-    PimCommonAutoCorrection::AutoCorrection autocorrection;
-    auto settings = new PimCommonAutoCorrection::AutoCorrectionSettings;
+#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
+    TextAutoCorrectionCore::AutoCorrection autocorrection;
+    auto settings = new TextAutoCorrectionCore::AutoCorrectionSettings;
+#else
+    TextAutoCorrection::AutoCorrection autocorrection;
+    auto settings = new TextAutoCorrection::AutoCorrectionSettings;
+#endif
     settings->setEnabledAutoCorrection(true);
     settings->setUppercaseFirstCharOfSentence(true);
     settings->setFixTwoUppercaseChars(true);
