@@ -1,18 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "composerattachmentinterface.h"
 using namespace MessageComposer;
-ComposerAttachmentInterface::ComposerAttachmentInterface()
-{
-}
+ComposerAttachmentInterface::ComposerAttachmentInterface() = default;
 
-ComposerAttachmentInterface::~ComposerAttachmentInterface()
-{
-}
+ComposerAttachmentInterface::~ComposerAttachmentInterface() = default;
 
 QStringList ComposerAttachmentInterface::fileNames() const
 {
