@@ -28,7 +28,6 @@
 #include "sendlater/sendlatercreatejob.h"
 #include "sendlater/sendlaterinfo.h"
 
-#include "helper/messagehelper.h"
 #include <PimCommonAkonadi/RecentAddresses>
 
 #include "settings/messagecomposersettings.h"
@@ -44,15 +43,15 @@
 #include <MessageCore/NodeHelper>
 #include <MessageCore/StringUtil>
 
+#include <Akonadi/MessageQueueJob>
 #include <MailTransport/TransportComboBox>
 #include <MailTransport/TransportManager>
-#include <MailTransportAkonadi/MessageQueueJob>
 
 #include <Akonadi/CollectionComboBox>
 #include <Akonadi/CollectionFetchJob>
 #include <Akonadi/ItemCreateJob>
-#include <Akonadi/KMime/MessageFlags>
-#include <Akonadi/KMime/SpecialMailCollections>
+#include <Akonadi/MessageFlags>
+#include <Akonadi/SpecialMailCollections>
 
 #include <KEmailAddress>
 #include <KIdentityManagement/IdentityCombo>
@@ -60,11 +59,13 @@
 
 #include "messagecomposer_debug.h"
 
+#include <Libkleo/ExpiryChecker>
+#include <Libkleo/ExpiryCheckerSettings>
+
 #include <QGpgME/ExportJob>
 #include <QGpgME/ImportJob>
 #include <QGpgME/Protocol>
 #include <gpgme++/context.h>
-#include <gpgme++/gpgmepp_version.h>
 #include <gpgme++/importresult.h>
 
 #include <KLocalizedString>
@@ -256,7 +257,7 @@ void ComposerViewBase::updateTemplate(const KMime::Message::Ptr &msg)
 
 void ComposerViewBase::saveMailSettings()
 {
-    const KIdentityManagement::Identity identity = identityManager()->identityForUoid(m_identityCombo->currentIdentity());
+    const auto identity = currentIdentity();
     auto header = new KMime::Headers::Generic("X-KMail-Transport");
     header->fromUnicodeString(QString::number(m_transport->currentTransportId()), "utf-8");
     m_msg->setHeader(header);
@@ -314,7 +315,7 @@ void ComposerViewBase::send(MessageComposer::MessageSender::SendMethod method, M
     mSaveIn = saveIn;
 
     KCursorSaver saver(Qt::WaitCursor);
-    const KIdentityManagement::Identity identity = identityManager()->identityForUoid(m_identityCombo->currentIdentity());
+    const auto identity = currentIdentity();
 
     if (identity.attachVcard() && m_attachmentController->attachOwnVcard()) {
         const QString vcardFileName = identity.vCardFile();
@@ -328,16 +329,16 @@ void ComposerViewBase::send(MessageComposer::MessageSender::SendMethod method, M
         const QString keepBtnText =
             m_encrypt ? m_sign ? i18n("&Keep markup, do not sign/encrypt") : i18n("&Keep markup, do not encrypt") : i18n("&Keep markup, do not sign");
         const QString yesBtnText = m_encrypt ? m_sign ? i18n("Sign/Encrypt (delete markup)") : i18n("Encrypt (delete markup)") : i18n("Sign (delete markup)");
-        int ret = KMessageBox::warningYesNoCancel(m_parentWidget,
-                                                  i18n("<qt><p>Inline signing/encrypting of HTML messages is not possible;</p>"
-                                                       "<p>do you want to delete your markup?</p></qt>"),
-                                                  i18n("Sign/Encrypt Message?"),
-                                                  KGuiItem(yesBtnText),
-                                                  KGuiItem(keepBtnText));
+        int ret = KMessageBox::warningTwoActionsCancel(m_parentWidget,
+                                                       i18n("<qt><p>Inline signing/encrypting of HTML messages is not possible;</p>"
+                                                            "<p>do you want to delete your markup?</p></qt>"),
+                                                       i18n("Sign/Encrypt Message?"),
+                                                       KGuiItem(yesBtnText),
+                                                       KGuiItem(keepBtnText));
         if (KMessageBox::Cancel == ret) {
             return;
         }
-        if (KMessageBox::No == ret) {
+        if (KMessageBox::ButtonCode::SecondaryAction == ret) {
             m_encrypt = false;
             m_sign = false;
         } else {
@@ -386,7 +387,7 @@ void ComposerViewBase::readyForSending()
 
     // first, expand all addresses
     auto job = new MessageComposer::EmailAddressResolveJob(this);
-    const KIdentityManagement::Identity identity = identityManager()->identityForUoid(m_identityCombo->currentIdentity());
+    const auto identity = currentIdentity();
     if (!identity.isNull()) {
         job->setDefaultDomainName(identity.defaultDomainName());
     }
@@ -521,12 +522,12 @@ void ComposerViewBase::slotEmailAddressResolved(KJob *job)
             if (m_attachmentModel) {
                 MessageComposer::Utils resizeUtils;
                 if (resizeUtils.containsImage(m_attachmentModel->attachments())) {
-                    const int rc = KMessageBox::warningYesNo(m_parentWidget,
-                                                             i18n("Do you want to resize images?"),
-                                                             i18n("Auto Resize Images"),
-                                                             KGuiItem(i18nc("@action:button", "Auto Resize")),
-                                                             KGuiItem(i18nc("@action:button", "Do Not Resize")));
-                    if (rc == KMessageBox::Yes) {
+                    const int rc = KMessageBox::warningTwoActions(m_parentWidget,
+                                                                  i18n("Do you want to resize images?"),
+                                                                  i18n("Auto Resize Images"),
+                                                                  KGuiItem(i18nc("@action:button", "Auto Resize")),
+                                                                  KGuiItem(i18nc("@action:button", "Do Not Resize")));
+                    if (rc == KMessageBox::ButtonCode::PrimaryAction) {
                         autoresizeImage = true;
                     } else {
                         autoresizeImage = false;
@@ -553,69 +554,62 @@ namespace
 {
 // helper methods for reading encryption settings
 
-inline int encryptKeyNearExpiryWarningThresholdInDays()
+inline Kleo::chrono::days encryptOwnKeyNearExpiryWarningThresholdInDays()
 {
     if (!MessageComposer::MessageComposerSettings::self()->cryptoWarnWhenNearExpire()) {
-        return -1;
+        return Kleo::chrono::days{-1};
+    }
+    const int num = MessageComposer::MessageComposerSettings::self()->cryptoWarnOwnEncrKeyNearExpiryThresholdDays();
+    return Kleo::chrono::days{qMax(1, num)};
+}
+
+inline Kleo::chrono::days encryptKeyNearExpiryWarningThresholdInDays()
+{
+    if (!MessageComposer::MessageComposerSettings::self()->cryptoWarnWhenNearExpire()) {
+        return Kleo::chrono::days{-1};
     }
     const int num = MessageComposer::MessageComposerSettings::self()->cryptoWarnEncrKeyNearExpiryThresholdDays();
-    return qMax(1, num);
+    return Kleo::chrono::days{qMax(1, num)};
 }
 
-inline int signingKeyNearExpiryWarningThresholdInDays()
+inline Kleo::chrono::days encryptRootCertNearExpiryWarningThresholdInDays()
 {
     if (!MessageComposer::MessageComposerSettings::self()->cryptoWarnWhenNearExpire()) {
-        return -1;
-    }
-    const int num = MessageComposer::MessageComposerSettings::self()->cryptoWarnSignKeyNearExpiryThresholdDays();
-    return qMax(1, num);
-}
-
-inline int encryptRootCertNearExpiryWarningThresholdInDays()
-{
-    if (!MessageComposer::MessageComposerSettings::self()->cryptoWarnWhenNearExpire()) {
-        return -1;
+        return Kleo::chrono::days{-1};
     }
     const int num = MessageComposer::MessageComposerSettings::self()->cryptoWarnEncrRootNearExpiryThresholdDays();
-    return qMax(1, num);
+    return Kleo::chrono::days{qMax(1, num)};
 }
 
-inline int signingRootCertNearExpiryWarningThresholdInDays()
+inline Kleo::chrono::days encryptChainCertNearExpiryWarningThresholdInDays()
 {
     if (!MessageComposer::MessageComposerSettings::self()->cryptoWarnWhenNearExpire()) {
-        return -1;
-    }
-    const int num = MessageComposer::MessageComposerSettings::self()->cryptoWarnSignRootNearExpiryThresholdDays();
-    return qMax(1, num);
-}
-
-inline int encryptChainCertNearExpiryWarningThresholdInDays()
-{
-    if (!MessageComposer::MessageComposerSettings::self()->cryptoWarnWhenNearExpire()) {
-        return -1;
+        return Kleo::chrono::days{-1};
     }
     const int num = MessageComposer::MessageComposerSettings::self()->cryptoWarnEncrChaincertNearExpiryThresholdDays();
-    return qMax(1, num);
-}
-
-inline int signingChainCertNearExpiryWarningThresholdInDays()
-{
-    if (!MessageComposer::MessageComposerSettings::self()->cryptoWarnWhenNearExpire()) {
-        return -1;
-    }
-    const int num = MessageComposer::MessageComposerSettings::self()->cryptoWarnSignChaincertNearExpiryThresholdDays();
-    return qMax(1, num);
-}
-
-inline bool encryptToSelf()
-{
-    return MessageComposer::MessageComposerSettings::self()->cryptoEncryptToSelf();
+    return Kleo::chrono::days{qMax(1, num)};
 }
 
 inline bool showKeyApprovalDialog()
 {
     return MessageComposer::MessageComposerSettings::self()->cryptoShowKeysForApproval();
 }
+
+inline bool cryptoWarningUnsigned(const KIdentityManagement::Identity &identity)
+{
+    if (identity.encryptionOverride()) {
+        return identity.warnNotSign();
+    }
+    return MessageComposer::MessageComposerSettings::self()->cryptoWarningUnsigned();
+}
+
+inline bool cryptoWarningUnencrypted(const KIdentityManagement::Identity &identity)
+{
+    if (identity.encryptionOverride()) {
+        return identity.warnNotEncrypt();
+    }
+    return MessageComposer::MessageComposerSettings::self()->cryptoWarningUnencrypted();
+}
 } // nameless namespace
 
 bool ComposerViewBase::addKeysToContext(const QString &gnupgHome,
@@ -637,8 +631,6 @@ bool ComposerViewBase::addKeysToContext(const QString &gnupgHome,
         }
     }
 
-    // qDebug() << "addKeysToContext: " << needSpecialContext;
-
     if (!needSpecialContext) {
         return false;
     }
@@ -682,9 +674,7 @@ bool ComposerViewBase::addKeysToContext(const QString &gnupgHome,
                 patterns << QString::fromUtf8(k.primaryFingerprint());
                 runningJobs++;
                 exportJob->start(patterns);
-#if GPGMEPP_VERSION >= 0x10E00 // 1.14.0
                 exportJob->setExportFlags(GpgME::Context::ExportMinimal);
-#endif
             } else {
                 qCDebug(MESSAGECOMPOSER_LOG) << "Adding " << k.primaryFingerprint() << "from Autocrypt storage";
                 const auto recipient = storage->getRecipient(it->second.toUtf8());
@@ -705,23 +695,52 @@ bool ComposerViewBase::addKeysToContext(const QString &gnupgHome,
     return true;
 }
 
+void ComposerViewBase::setAkonadiLookupEnabled(bool akonadiLookupEnabled)
+{
+    m_akonadiLookupEnabled = akonadiLookupEnabled;
+}
+
 QVector<MessageComposer::Composer *> ComposerViewBase::generateCryptoMessages(bool &wasCanceled)
 {
-    const KIdentityManagement::Identity &id = m_identMan->identityForUoidOrDefault(m_identityCombo->currentIdentity());
+    const auto id = currentIdentity();
+
+    bool canceled = false;
 
     qCDebug(MESSAGECOMPOSER_LOG) << "filling crypto info";
-    QScopedPointer<Kleo::KeyResolver> keyResolver(new Kleo::KeyResolver(encryptToSelf(),
-                                                                        showKeyApprovalDialog(),
-                                                                        id.pgpAutoEncrypt(),
-                                                                        m_cryptoMessageFormat,
-                                                                        encryptKeyNearExpiryWarningThresholdInDays(),
-                                                                        signingKeyNearExpiryWarningThresholdInDays(),
-                                                                        encryptRootCertNearExpiryWarningThresholdInDays(),
-                                                                        signingRootCertNearExpiryWarningThresholdInDays(),
-                                                                        encryptChainCertNearExpiryWarningThresholdInDays(),
-                                                                        signingChainCertNearExpiryWarningThresholdInDays()));
+    connect(expiryChecker().get(),
+            &Kleo::ExpiryChecker::expiryMessage,
+            this,
+            [&canceled](const GpgME::Key &key, QString msg, Kleo::ExpiryChecker::ExpiryInformation info, bool isNewMessage) {
+                if (!isNewMessage) {
+                    return;
+                }
 
-    keyResolver->setAutocryptEnabled(id.autocryptEnabled());
+                if (canceled) {
+                    return;
+                }
+                QString title;
+                QString dontAskAgainName;
+                if (info == Kleo::ExpiryChecker::OwnKeyExpired || info == Kleo::ExpiryChecker::OwnKeyNearExpiry) {
+                    dontAskAgainName = QStringLiteral("own key expires soon warning");
+                } else {
+                    dontAskAgainName = QStringLiteral("other encryption key near expiry warning");
+                }
+                if (info == Kleo::ExpiryChecker::OwnKeyExpired || info == Kleo::ExpiryChecker::OtherKeyExpired) {
+                    title = key.protocol() == GpgME::OpenPGP ? i18n("OpenPGP Key Expired") : i18n("S/MIME Certificate Expired");
+                } else {
+                    title = key.protocol() == GpgME::OpenPGP ? i18n("OpenPGP Key Expires Soon") : i18n("S/MIME Certificate Expires Soon");
+                }
+                if (KMessageBox::warningContinueCancel(nullptr, msg, title, KStandardGuiItem::cont(), KStandardGuiItem::cancel(), dontAskAgainName)
+                    == KMessageBox::Cancel) {
+                    canceled = true;
+                }
+            });
+
+    QScopedPointer<Kleo::KeyResolver> keyResolver(
+        new Kleo::KeyResolver(true, showKeyApprovalDialog(), id.pgpAutoEncrypt(), m_cryptoMessageFormat, expiryChecker()));
+
+    keyResolver->setAutocryptEnabled(autocryptEnabled());
+    keyResolver->setAkonadiLookupEnabled(m_akonadiLookupEnabled);
 
     QStringList encryptToSelfKeys;
     QStringList signKeys;
@@ -732,16 +751,15 @@ QVector<MessageComposer::Composer *> ComposerViewBase::generateCryptoMessages(bo
     bool doEncryptCompletely = m_encrypt;
 
     // Add encryptionkeys from id to keyResolver
-    qCDebug(MESSAGECOMPOSER_LOG) << id.pgpEncryptionKey().isEmpty() << id.smimeEncryptionKey().isEmpty();
     if (!id.pgpEncryptionKey().isEmpty()) {
         encryptToSelfKeys.push_back(QLatin1String(id.pgpEncryptionKey()));
     }
     if (!id.smimeEncryptionKey().isEmpty()) {
         encryptToSelfKeys.push_back(QLatin1String(id.smimeEncryptionKey()));
     }
-    if (keyResolver->setEncryptToSelfKeys(encryptToSelfKeys) != Kleo::Ok) {
+    if (canceled || keyResolver->setEncryptToSelfKeys(encryptToSelfKeys) != Kleo::Ok) {
         qCDebug(MESSAGECOMPOSER_LOG) << "Failed to set encryptoToSelf keys!";
-        return QVector<MessageComposer::Composer *>();
+        return {};
     }
 
     // Add signingkeys from id to keyResolver
@@ -751,9 +769,9 @@ QVector<MessageComposer::Composer *> ComposerViewBase::generateCryptoMessages(bo
     if (!id.smimeSigningKey().isEmpty()) {
         signKeys.push_back(QLatin1String(id.smimeSigningKey()));
     }
-    if (keyResolver->setSigningKeys(signKeys) != Kleo::Ok) {
+    if (canceled || keyResolver->setSigningKeys(signKeys) != Kleo::Ok) {
         qCDebug(MESSAGECOMPOSER_LOG) << "Failed to set signing keys!";
-        return QVector<MessageComposer::Composer *>();
+        return {};
     }
 
     if (m_attachmentModel) {
@@ -779,7 +797,7 @@ QVector<MessageComposer::Composer *> ComposerViewBase::generateCryptoMessages(bo
     keyResolver->setSecondaryRecipients(bcc);
 
     bool result = true;
-    bool canceled = false;
+    canceled = false;
     signSomething = determineWhetherToSign(doSignCompletely, keyResolver.data(), signSomething, result, canceled);
     if (!result) {
         // TODO handle failure
@@ -790,7 +808,7 @@ QVector<MessageComposer::Composer *> ComposerViewBase::generateCryptoMessages(bo
             Q_EMIT failed(QString());
         }
         wasCanceled = canceled;
-        return QVector<MessageComposer::Composer *>();
+        return {};
     }
 
     canceled = false;
@@ -805,33 +823,44 @@ QVector<MessageComposer::Composer *> ComposerViewBase::generateCryptoMessages(bo
         }
 
         wasCanceled = canceled;
-        return QVector<MessageComposer::Composer *>();
+        return {};
     }
 
+    QVector<MessageComposer::Composer *> composers;
+
     // No encryption or signing is needed
     if (!signSomething && !encryptSomething) {
-        return QVector<MessageComposer::Composer *>() << new MessageComposer::Composer();
+        auto composer = new MessageComposer::Composer;
+        if (m_cryptoMessageFormat & Kleo::OpenPGPMIMEFormat) {
+            composer->setAutocryptEnabled(autocryptEnabled());
+            if (keyResolver->encryptToSelfKeysFor(Kleo::OpenPGPMIMEFormat).size() > 0) {
+                composer->setSenderEncryptionKey(keyResolver->encryptToSelfKeysFor(Kleo::OpenPGPMIMEFormat)[0]);
+            }
+        }
+        composers.append(composer);
+        return composers;
     }
 
+    canceled = false;
     const Kleo::Result kpgpResult = keyResolver->resolveAllKeys(signSomething, encryptSomething);
-    if (kpgpResult == Kleo::Canceled) {
+    if (kpgpResult == Kleo::Canceled || canceled) {
         qCDebug(MESSAGECOMPOSER_LOG) << "resolveAllKeys: one key resolution canceled by user";
-        return QVector<MessageComposer::Composer *>();
+        return {};
     } else if (kpgpResult != Kleo::Ok) {
         // TODO handle failure
         qCDebug(MESSAGECOMPOSER_LOG) << "resolveAllKeys: failed to resolve keys! oh noes";
         Q_EMIT failed(i18n("Failed to resolve keys. Please report a bug."));
-        return QVector<MessageComposer::Composer *>();
+        return {};
     }
-    qCDebug(MESSAGECOMPOSER_LOG) << "done resolving keys:";
 
-    QVector<MessageComposer::Composer *> composers;
+    qCDebug(MESSAGECOMPOSER_LOG) << "done resolving keys.";
 
     if (encryptSomething || signSomething) {
         Kleo::CryptoMessageFormat concreteFormat = Kleo::AutoFormat;
         for (unsigned int i = 0; i < numConcreteCryptoMessageFormats; ++i) {
             concreteFormat = concreteCryptoMessageFormats[i];
-            if (keyResolver->encryptionItems(concreteFormat).empty()) {
+            const auto encData = keyResolver->encryptionItems(concreteFormat);
+            if (encData.empty()) {
                 continue;
             }
 
@@ -841,20 +870,18 @@ QVector<MessageComposer::Composer *> ComposerViewBase::generateCryptoMessages(bo
 
             auto composer = new MessageComposer::Composer;
 
-            if (encryptSomething) {
-                std::vector<Kleo::KeyResolver::SplitInfo> encData = keyResolver->encryptionItems(concreteFormat);
-                std::vector<Kleo::KeyResolver::SplitInfo>::iterator it;
+            if (encryptSomething || autocryptEnabled()) {
                 auto end(encData.end());
                 QVector<QPair<QStringList, std::vector<GpgME::Key>>> data;
                 data.reserve(encData.size());
-                for (it = encData.begin(); it != end; ++it) {
+                for (auto it = encData.begin(); it != end; ++it) {
                     QPair<QStringList, std::vector<GpgME::Key>> p(it->recipients, it->keys);
                     data.append(p);
                     qCDebug(MESSAGECOMPOSER_LOG) << "got resolved keys for:" << it->recipients;
                 }
                 composer->setEncryptionKeys(data);
-                if (concreteFormat & Kleo::OpenPGPMIMEFormat && id.autocryptEnabled()) {
-                    composer->setAutocryptEnabled(id.autocryptEnabled());
+                if (concreteFormat & Kleo::OpenPGPMIMEFormat && autocryptEnabled()) {
+                    composer->setAutocryptEnabled(autocryptEnabled());
                     composer->setSenderEncryptionKey(keyResolver->encryptToSelfKeysFor(concreteFormat)[0]);
                     QTemporaryDir dir;
                     bool specialGnupgHome = addKeysToContext(dir.path(), data, keyResolver->useAutocrypt());
@@ -885,7 +912,7 @@ QVector<MessageComposer::Composer *> ComposerViewBase::generateCryptoMessages(bo
     }
 
     if (composers.isEmpty() && (signSomething || encryptSomething)) {
-        Q_ASSERT_X(false, "ComposerViewBase::fillCryptoInfo", "No concrete sign or encrypt method selected");
+        Q_ASSERT_X(false, "ComposerViewBase::generateCryptoMessages", "No concrete sign or encrypt method selected");
     }
 
     return composers;
@@ -1068,22 +1095,22 @@ void ComposerViewBase::saveRecentAddresses(const KMime::Message::Ptr &msg)
 void ComposerViewBase::queueMessage(const KMime::Message::Ptr &message, MessageComposer::Composer *composer)
 {
     const MessageComposer::InfoPart *infoPart = composer->infoPart();
-    auto qjob = new MailTransport::MessageQueueJob(this);
+    auto qjob = new Akonadi::MessageQueueJob(this);
     qjob->setMessage(message);
     qjob->transportAttribute().setTransportId(infoPart->transportId());
     if (mSendMethod == MessageComposer::MessageSender::SendLater) {
-        qjob->dispatchModeAttribute().setDispatchMode(MailTransport::DispatchModeAttribute::Manual);
+        qjob->dispatchModeAttribute().setDispatchMode(Akonadi::DispatchModeAttribute::Manual);
     }
 
     if (message->hasHeader("X-KMail-FccDisabled")) {
-        qjob->sentBehaviourAttribute().setSentBehaviour(MailTransport::SentBehaviourAttribute::Delete);
+        qjob->sentBehaviourAttribute().setSentBehaviour(Akonadi::SentBehaviourAttribute::Delete);
     } else if (!infoPart->fcc().isEmpty()) {
-        qjob->sentBehaviourAttribute().setSentBehaviour(MailTransport::SentBehaviourAttribute::MoveToCollection);
+        qjob->sentBehaviourAttribute().setSentBehaviour(Akonadi::SentBehaviourAttribute::MoveToCollection);
 
         const Akonadi::Collection sentCollection(infoPart->fcc().toLongLong());
         qjob->sentBehaviourAttribute().setMoveToCollection(sentCollection);
     } else {
-        qjob->sentBehaviourAttribute().setSentBehaviour(MailTransport::SentBehaviourAttribute::MoveToDefaultSentCollection);
+        qjob->sentBehaviourAttribute().setSentBehaviour(Akonadi::SentBehaviourAttribute::MoveToDefaultSentCollection);
     }
 
     MailTransport::Transport *transport = MailTransport::TransportManager::self()->transportById(infoPart->transportId());
@@ -1113,7 +1140,7 @@ void ComposerViewBase::queueMessage(const KMime::Message::Ptr &message, MessageC
 
     MessageComposer::Util::addCustomHeaders(message, m_customHeader);
     message->assemble();
-    connect(qjob, &MailTransport::MessageQueueJob::result, this, &ComposerViewBase::slotQueueResult);
+    connect(qjob, &Akonadi::MessageQueueJob::result, this, &ComposerViewBase::slotQueueResult);
     m_pendingQueueJobs++;
     qjob->start();
 
@@ -1123,7 +1150,7 @@ void ComposerViewBase::queueMessage(const KMime::Message::Ptr &message, MessageC
 void ComposerViewBase::slotQueueResult(KJob *job)
 {
     m_pendingQueueJobs--;
-    auto qjob = static_cast<MailTransport::MessageQueueJob *>(job);
+    auto qjob = static_cast<Akonadi::MessageQueueJob *>(job);
     qCDebug(MESSAGECOMPOSER_LOG) << "mPendingQueueJobs" << m_pendingQueueJobs;
     Q_ASSERT(m_pendingQueueJobs >= 0);
 
@@ -1254,11 +1281,10 @@ void ComposerViewBase::autoSaveMessage()
         return;
     }
 
-    const KIdentityManagement::Identity &id = m_identMan->identityForUoidOrDefault(m_identityCombo->currentIdentity());
     auto composer = new Composer();
     fillComposer(composer);
     composer->setAutoSave(true);
-    composer->setAutocryptEnabled(id.autocryptEnabled());
+    composer->setAutocryptEnabled(autocryptEnabled());
     m_composers.append(composer);
     connect(composer, &MessageComposer::Composer::result, this, &ComposerViewBase::slotAutoSaveComposeResult);
     composer->start();
@@ -1329,7 +1355,7 @@ void ComposerViewBase::writeAutoSaveToDisk(const KMime::Message::Ptr &message)
     if (!errorMessage.isEmpty()) {
         qCWarning(MESSAGECOMPOSER_LOG) << "Auto saving failed:" << errorMessage << file.errorString() << " m_autoSaveUUID" << m_autoSaveUUID;
         if (!m_autoSaveErrorShown) {
-            KMessageBox::sorry(m_parentWidget,
+            KMessageBox::error(m_parentWidget,
                                i18n("Autosaving the message as %1 failed.\n"
                                     "%2\n"
                                     "Reason: %3",
@@ -1352,7 +1378,7 @@ void ComposerViewBase::writeAutoSaveToDisk(const KMime::Message::Ptr &message)
 void ComposerViewBase::saveMessage(const KMime::Message::Ptr &message, MessageComposer::MessageSender::SaveIn saveIn)
 {
     Akonadi::Collection target;
-    const KIdentityManagement::Identity identity = identityManager()->identityForUoid(m_identityCombo->currentIdentity());
+    const auto identity = currentIdentity();
     message->date()->setDateTime(QDateTime::currentDateTime());
     if (!identity.isNull()) {
         if (auto header = message->headerByType("X-KMail-Fcc")) {
@@ -1526,7 +1552,6 @@ void ComposerViewBase::addAttachmentPart(KMime::Content *partToAttach)
     m_attachmentController->addAttachment(part);
 }
 
-
 void ComposerViewBase::fillComposer(MessageComposer::Composer *composer)
 {
     fillComposer(composer, UseUnExpandedRecipients, false);
@@ -1587,6 +1612,16 @@ QString ComposerViewBase::subject() const
     return MessageComposer::Util::cleanedUpHeaderString(m_subject);
 }
 
+const KIdentityManagement::Identity &ComposerViewBase::currentIdentity() const
+{
+    return m_identMan->identityForUoidOrDefault(m_identityCombo->currentIdentity());
+}
+
+bool ComposerViewBase::autocryptEnabled() const
+{
+    return currentIdentity().autocryptEnabled();
+}
+
 void ComposerViewBase::setParentWidgetForGui(QWidget *w)
 {
     m_parentWidget = w;
@@ -1857,17 +1892,18 @@ ComposerViewBase::MissingAttachment ComposerViewBase::checkForMissingAttachments
     if (!hasMissingAttachments(attachmentKeywords)) {
         return NoMissingAttachmentFound;
     }
-    int rc = KMessageBox::warningYesNoCancel(m_editor,
-                                             i18n("The message you have composed seems to refer to an "
-                                                  "attached file but you have not attached anything.\n"
-                                                  "Do you want to attach a file to your message?"),
-                                             i18n("File Attachment Reminder"),
-                                             KGuiItem(i18n("&Attach File...")),
-                                             KGuiItem(i18n("&Send as Is")));
+    const int rc = KMessageBox::warningTwoActionsCancel(m_editor,
+
+                                                        i18n("The message you have composed seems to refer to an "
+                                                             "attached file but you have not attached anything.\n"
+                                                             "Do you want to attach a file to your message?"),
+                                                        i18n("File Attachment Reminder"),
+                                                        KGuiItem(i18n("&Attach File..."), QLatin1String("mail-attachment")),
+                                                        KGuiItem(i18n("&Send as Is"), QLatin1String("mail-send")));
     if (rc == KMessageBox::Cancel) {
         return FoundMissingAttachmentAndCancel;
     }
-    if (rc == KMessageBox::Yes) {
+    if (rc == KMessageBox::ButtonCode::PrimaryAction) {
         m_attachmentController->showAddAttachmentFileDialog();
         return FoundMissingAttachmentAndAddedAttachment;
     }
@@ -1919,16 +1955,19 @@ bool ComposerViewBase::determineWhetherToSign(bool doSignCompletely, Kleo::KeyRe
             "yielded that you be asked whether or not to sign "
             "this message.\n"
             "Sign this message?");
-        switch (
-            KMessageBox::questionYesNoCancel(m_parentWidget, msg, i18n("Sign Message?"), KGuiItem(i18nc("to sign", "&Sign")), KGuiItem(i18n("Do &Not Sign")))) {
+        switch (KMessageBox::warningTwoActionsCancel(m_parentWidget,
+                                                     msg,
+                                                     i18n("Sign Message?"),
+                                                     KGuiItem(i18nc("to sign", "&Sign")),
+                                                     KGuiItem(i18n("Do &Not Sign")))) {
         case KMessageBox::Cancel:
             result = false;
             canceled = true;
             return false;
-        case KMessageBox::Yes:
+        case KMessageBox::ButtonCode::PrimaryAction:
             markAllAttachmentsForSigning(true);
             return true;
-        case KMessageBox::No:
+        case KMessageBox::ButtonCode::SecondaryAction:
             markAllAttachmentsForSigning(false);
             return false;
         default:
@@ -1944,16 +1983,19 @@ bool ComposerViewBase::determineWhetherToSign(bool doSignCompletely, Kleo::KeyRe
             "There are conflicting signing preferences "
             "for these recipients.\n"
             "Sign this message?");
-        switch (
-            KMessageBox::warningYesNoCancel(m_parentWidget, msg, i18n("Sign Message?"), KGuiItem(i18nc("to sign", "&Sign")), KGuiItem(i18n("Do &Not Sign")))) {
+        switch (KMessageBox::warningTwoActionsCancel(m_parentWidget,
+                                                     msg,
+                                                     i18n("Sign Message?"),
+                                                     KGuiItem(i18nc("to sign", "&Sign")),
+                                                     KGuiItem(i18n("Do &Not Sign")))) {
         case KMessageBox::Cancel:
             result = false;
             canceled = true;
             return false;
-        case KMessageBox::Yes:
+        case KMessageBox::ButtonCode::PrimaryAction:
             markAllAttachmentsForSigning(true);
             return true;
-        case KMessageBox::No:
+        case KMessageBox::ButtonCode::SecondaryAction:
             markAllAttachmentsForSigning(false);
             return false;
         default:
@@ -1979,7 +2021,7 @@ bool ComposerViewBase::determineWhetherToSign(bool doSignCompletely, Kleo::KeyRe
     }
 
     if (!sign || !doSignCompletely) {
-        if (MessageComposer::MessageComposerSettings::self()->cryptoWarningUnsigned()) {
+        if (cryptoWarningUnsigned(currentIdentity())) {
             KCursorSaver saver(Qt::WaitCursor);
             const QString msg = sign && !doSignCompletely ? i18n(
                                     "Some parts of this message will not be signed.\n"
@@ -1990,16 +2032,19 @@ bool ComposerViewBase::determineWhetherToSign(bool doSignCompletely, Kleo::KeyRe
                                                               "Sending unsigned message might violate site policy.\n"
                                                               "Sign message instead?"); // oh, I hate this...
             const QString buttonText = sign && !doSignCompletely ? i18n("&Sign All Parts") : i18n("&Sign");
-            switch (
-                KMessageBox::warningYesNoCancel(m_parentWidget, msg, i18n("Unsigned-Message Warning"), KGuiItem(buttonText), KGuiItem(i18n("Send &As Is")))) {
+            switch (KMessageBox::warningTwoActionsCancel(m_parentWidget,
+                                                         msg,
+                                                         i18n("Unsigned-Message Warning"),
+                                                         KGuiItem(buttonText),
+                                                         KGuiItem(i18n("Send &As Is")))) {
             case KMessageBox::Cancel:
                 result = false;
                 canceled = true;
                 return false;
-            case KMessageBox::Yes:
+            case KMessageBox::ButtonCode::PrimaryAction:
                 markAllAttachmentsForSigning(true);
                 return true;
-            case KMessageBox::No:
+            case KMessageBox::ButtonCode::SecondaryAction:
                 return sign || doSignCompletely;
             default:
                 qCWarning(MESSAGECOMPOSER_LOG) << "Unhandled MessageBox response";
@@ -2045,19 +2090,19 @@ bool ComposerViewBase::determineWhetherToEncrypt(bool doEncryptCompletely,
                                               "yielded that you be asked whether or not to encrypt "
                                               "this message.\n"
                                               "Encrypt this message?");
-        switch (KMessageBox::questionYesNoCancel(m_parentWidget,
-                                                 msg,
-                                                 i18n("Encrypt Message?"),
-                                                 KGuiItem(signSomething ? i18n("Sign && &Encrypt") : i18n("&Encrypt")),
-                                                 KGuiItem(signSomething ? i18n("&Sign Only") : i18n("&Send As-Is")))) {
+        switch (KMessageBox::warningTwoActionsCancel(m_parentWidget,
+                                                     msg,
+                                                     i18n("Encrypt Message?"),
+                                                     KGuiItem(signSomething ? i18n("Sign && &Encrypt") : i18n("&Encrypt")),
+                                                     KGuiItem(signSomething ? i18n("&Sign Only") : i18n("&Send As-Is")))) {
         case KMessageBox::Cancel:
             result = false;
             canceled = true;
             return false;
-        case KMessageBox::Yes:
+        case KMessageBox::ButtonCode::PrimaryAction:
             markAllAttachmentsForEncryption(true);
             return true;
-        case KMessageBox::No:
+        case KMessageBox::ButtonCode::SecondaryAction:
             markAllAttachmentsForEncryption(false);
             return false;
         default:
@@ -2073,15 +2118,21 @@ bool ComposerViewBase::determineWhetherToEncrypt(bool doEncryptCompletely,
             "There are conflicting encryption preferences "
             "for these recipients.\n"
             "Encrypt this message?");
-        switch (KMessageBox::warningYesNoCancel(m_parentWidget, msg, i18n("Encrypt Message?"), KGuiItem(i18n("&Encrypt")), KGuiItem(i18n("Do &Not Encrypt")))) {
+        switch (KMessageBox::warningTwoActionsCancel(
+
+            m_parentWidget,
+            msg,
+            i18n("Encrypt Message?"),
+            KGuiItem(i18n("&Encrypt")),
+            KGuiItem(i18n("Do &Not Encrypt")))) {
         case KMessageBox::Cancel:
             result = false;
             canceled = true;
             return false;
-        case KMessageBox::Yes:
+        case KMessageBox::ButtonCode::PrimaryAction:
             markAllAttachmentsForEncryption(true);
             return true;
-        case KMessageBox::No:
+        case KMessageBox::ButtonCode::SecondaryAction:
             markAllAttachmentsForEncryption(false);
             return false;
         default:
@@ -2108,7 +2159,7 @@ bool ComposerViewBase::determineWhetherToEncrypt(bool doEncryptCompletely,
     }
 
     if (!encrypt || !doEncryptCompletely) {
-        if (MessageComposer::MessageComposerSettings::self()->cryptoWarningUnencrypted()) {
+        if (cryptoWarningUnencrypted(currentIdentity())) {
             KCursorSaver saver(Qt::WaitCursor);
             const QString msg = !doEncryptCompletely ? i18n(
                                     "Some parts of this message will not be encrypted.\n"
@@ -2121,19 +2172,19 @@ bool ComposerViewBase::determineWhetherToEncrypt(bool doEncryptCompletely,
                                                          "leak sensitive information.\n"
                                                          "Encrypt messages instead?"); // oh, I hate this...
             const QString buttonText = !doEncryptCompletely ? i18n("&Encrypt All Parts") : i18n("&Encrypt");
-            switch (KMessageBox::warningYesNoCancel(m_parentWidget,
-                                                    msg,
-                                                    i18n("Unencrypted Message Warning"),
-                                                    KGuiItem(buttonText),
-                                                    KGuiItem(signSomething ? i18n("&Sign Only") : i18n("&Send As-Is")))) {
+            switch (KMessageBox::warningTwoActionsCancel(m_parentWidget,
+                                                         msg,
+                                                         i18n("Unencrypted Message Warning"),
+                                                         KGuiItem(buttonText),
+                                                         KGuiItem(signSomething ? i18n("&Sign Only") : i18n("&Send As-Is")))) {
             case KMessageBox::Cancel:
                 result = false;
                 canceled = true;
                 return false;
-            case KMessageBox::Yes:
+            case KMessageBox::ButtonCode::PrimaryAction:
                 markAllAttachmentsForEncryption(true);
                 return true;
-            case KMessageBox::No:
+            case KMessageBox::ButtonCode::SecondaryAction:
                 return encrypt || doEncryptCompletely;
             default:
                 qCWarning(MESSAGECOMPOSER_LOG) << "Unhandled MessageBox response";
@@ -2192,3 +2243,14 @@ KMime::Message::Ptr ComposerViewBase::msg() const
 {
     return m_msg;
 }
+
+std::shared_ptr<Kleo::ExpiryChecker> ComposerViewBase::expiryChecker()
+{
+    if (!mExpiryChecker) {
+        mExpiryChecker.reset(new Kleo::ExpiryChecker{Kleo::ExpiryCheckerSettings{encryptOwnKeyNearExpiryWarningThresholdInDays(),
+                                                                                 encryptKeyNearExpiryWarningThresholdInDays(),
+                                                                                 encryptRootCertNearExpiryWarningThresholdInDays(),
+                                                                                 encryptChainCertNearExpiryWarningThresholdInDays()}});
+    }
+    return mExpiryChecker;
+}
