@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_COMPOSERVIEWINTERFACE_H
-#define MESSAGECOMPOSER_COMPOSERVIEWINTERFACE_H
+#pragma once
 #include "messagecomposer_export.h"
 #include <MessageComposer/ComposerAttachmentInterface>
 #include <QString>
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class ComposerViewBase;
 /**
  * @brief The ComposerViewInterface class
@@ -25,7 +25,9 @@ public:
     Q_REQUIRED_RESULT QString subject() const;
     Q_REQUIRED_RESULT QString to() const;
     Q_REQUIRED_RESULT QString cc() const;
+    Q_REQUIRED_RESULT QString bcc() const;
     Q_REQUIRED_RESULT QString from() const;
+    Q_REQUIRED_RESULT QString replyTo() const;
 
     Q_REQUIRED_RESULT MessageComposer::ComposerAttachmentInterface attachments() const;
 
@@ -34,9 +36,8 @@ public:
     Q_REQUIRED_RESULT QString shortTime() const;
     Q_REQUIRED_RESULT QString longTime() const;
     Q_REQUIRED_RESULT QString insertDayOfWeek() const;
+
 private:
     ComposerViewBase *const mComposerView;
 };
 }
-
-#endif // COMPOSERVIEWINTERFACE_H
