@@ -12,14 +12,17 @@
 */
 
 #include "composer/keyresolver.h"
-#include "composer/nearexpirychecker.h"
+
 #include "contactpreference/savecontactpreferencejob.h"
 
 #include "utils/kleo_util.h"
 #include <KCursorSaver>
 
 #include <KEmailAddress>
-#include <Libkleo/Dn>
+
+#include <Libkleo/Algorithm>
+#include <Libkleo/Compliance>
+#include <Libkleo/ExpiryChecker>
 #include <Libkleo/KeySelectionDialog>
 
 #include <QGpgME/KeyListJob>
@@ -64,7 +67,11 @@ static inline QString ItemDotAddress(const Kleo::KeyResolver::Item &item)
 
 static inline bool ApprovalNeeded(const Kleo::KeyResolver::Item &item)
 {
-    return item.pref == Kleo::NeverEncrypt || item.keys.empty();
+    bool approvalNeeded = item.pref == Kleo::NeverEncrypt || item.keys.empty();
+    if (!approvalNeeded && Kleo::DeVSCompliance::isCompliant()) {
+        approvalNeeded = !Kleo::all_of(item.keys, &Kleo::DeVSCompliance::keyIsCompliant);
+    }
+    return approvalNeeded;
 }
 
 static inline Kleo::KeyResolver::Item CopyKeysAndEncryptionPreferences(const Kleo::KeyResolver::Item &oldItem, const Kleo::KeyApprovalDialog::Item &newItem)
@@ -338,7 +345,7 @@ static std::vector<GpgME::Key> trustedOrConfirmed(const std::vector<GpgME::Key>
 
 namespace
 {
-struct IsNotForFormat : public std::unary_function<GpgME::Key, bool> {
+struct IsNotForFormat : public std::function<bool(GpgME::Key)> {
     IsNotForFormat(Kleo::CryptoMessageFormat f)
         : format(f)
     {
@@ -352,7 +359,7 @@ struct IsNotForFormat : public std::unary_function<GpgME::Key, bool> {
     const Kleo::CryptoMessageFormat format;
 };
 
-struct IsForFormat : std::unary_function<GpgME::Key, bool> {
+struct IsForFormat : std::function<bool(GpgME::Key)> {
     explicit IsForFormat(Kleo::CryptoMessageFormat f)
         : protocol(isOpenPGP(f)     ? GpgME::OpenPGP
                        : isSMIME(f) ? GpgME::CMS
@@ -369,7 +376,7 @@ struct IsForFormat : std::unary_function<GpgME::Key, bool> {
 };
 }
 
-class Kleo::KeyResolver::SigningPreferenceCounter : public std::unary_function<Kleo::KeyResolver::Item, void>
+class Kleo::KeyResolver::SigningPreferenceCounter : public std::function<void(Kleo::KeyResolver::Item)>
 {
 public:
     SigningPreferenceCounter() = default;
@@ -410,7 +417,7 @@ void Kleo::KeyResolver::SigningPreferenceCounter::operator()(const Kleo::KeyReso
     ++mTotal;
 }
 
-class Kleo::KeyResolver::EncryptionPreferenceCounter : public std::unary_function<Item, void>
+class Kleo::KeyResolver::EncryptionPreferenceCounter : public std::function<void(Item)>
 {
     const Kleo::KeyResolver *_this;
 
@@ -477,7 +484,7 @@ void Kleo::KeyResolver::EncryptionPreferenceCounter::operator()(Item &item)
 
 namespace
 {
-class FormatPreferenceCounterBase : public std::unary_function<Kleo::KeyResolver::Item, void>
+class FormatPreferenceCounterBase : public std::function<void(Kleo::KeyResolver::Item)>
 {
 public:
     FormatPreferenceCounterBase() = default;
@@ -608,21 +615,17 @@ struct Q_DECL_HIDDEN Kleo::KeyResolver::KeyResolverPrivate {
     using ContactPreferencesMap = std::map<QString, MessageComposer::ContactPreference>;
     ContactPreferencesMap mContactPreferencesMap;
     std::map<QByteArray, QString> mAutocryptMap;
-    MessageComposer::NearExpiryChecker::Ptr nearExpiryChecker;
+    std::shared_ptr<Kleo::ExpiryChecker> expiryChecker;
 };
 
-Kleo::KeyResolver::KeyResolver(bool encToSelf,
-                               bool showApproval,
-                               bool oppEncryption,
-                               unsigned int f,
-                               const MessageComposer::NearExpiryCheckerPtr &nearExpiryChecker)
+Kleo::KeyResolver::KeyResolver(bool encToSelf, bool showApproval, bool oppEncryption, unsigned int f, const std::shared_ptr<Kleo::ExpiryChecker> &expiryChecker)
     : d(new KeyResolverPrivate)
     , mEncryptToSelf(encToSelf)
     , mShowApprovalDialog(showApproval)
     , mOpportunisticEncyption(oppEncryption)
     , mCryptoMessageFormats(f)
 {
-    d->nearExpiryChecker = nearExpiryChecker;
+    d->expiryChecker = expiryChecker;
 }
 
 Kleo::KeyResolver::~KeyResolver() = default;
@@ -665,11 +668,11 @@ Kleo::Result Kleo::KeyResolver::setEncryptToSelfKeys(const QStringList &fingerpr
     std::vector<GpgME::Key>::const_iterator end(d->mOpenPGPEncryptToSelfKeys.end());
 
     for (auto it = d->mOpenPGPEncryptToSelfKeys.begin(); it != end; ++it) {
-        d->nearExpiryChecker->checkOwnKey(*it);
+        d->expiryChecker->checkKey(*it, Kleo::ExpiryChecker::OwnEncryptionKey);
     }
     std::vector<GpgME::Key>::const_iterator end2(d->mSMIMEEncryptToSelfKeys.end());
     for (auto it = d->mSMIMEEncryptToSelfKeys.begin(); it != end2; ++it) {
-        d->nearExpiryChecker->checkOwnKey(*it);
+        d->expiryChecker->checkKey(*it, Kleo::ExpiryChecker::OwnEncryptionKey);
     }
 
     return Kleo::Ok;
@@ -706,11 +709,11 @@ Kleo::Result Kleo::KeyResolver::setSigningKeys(const QStringList &fingerprints)
     // check for near expiry:
 
     for (auto it = d->mOpenPGPSigningKeys.begin(), total = d->mOpenPGPSigningKeys.end(); it != total; ++it) {
-        d->nearExpiryChecker->checkOwnSigningKey(*it);
+        d->expiryChecker->checkKey(*it, Kleo::ExpiryChecker::OwnSigningKey);
     }
 
     for (auto it = d->mSMIMESigningKeys.begin(), total = d->mSMIMESigningKeys.end(); it != total; ++it) {
-        d->nearExpiryChecker->checkOwnSigningKey(*it);
+        d->expiryChecker->checkKey(*it, Kleo::ExpiryChecker::OwnSigningKey);
     }
 
     return Kleo::Ok;
@@ -976,7 +979,7 @@ Kleo::Result Kleo::KeyResolver::resolveEncryptionKeys(bool signingRequested, boo
         const std::vector<SplitInfo> si_list = encryptionItems(concreteCryptoMessageFormats[i]);
         for (auto sit = si_list.begin(), total = si_list.end(); sit != total; ++sit) {
             for (auto kit = sit->keys.begin(); kit != sit->keys.end(); ++kit) {
-                d->nearExpiryChecker->checkKey(*kit);
+                d->expiryChecker->checkKey(*kit, Kleo::ExpiryChecker::EncryptionKey);
             }
         }
     }
@@ -1652,12 +1655,17 @@ MessageComposer::ContactPreference Kleo::KeyResolver::lookupContactPreferences(c
         KContacts::Addressee addr = res.at(0);
         pref.fillFromAddressee(addr);
     }
-    // insert into map and grab resulting iterator
-    d->mContactPreferencesMap.insert(std::make_pair(address, pref));
+
+    const_cast<KeyResolver *>(this)->setContactPreferences(address, pref);
 
     return pref;
 }
 
+void Kleo::KeyResolver::setContactPreferences(const QString &address, const MessageComposer::ContactPreference &pref)
+{
+    d->mContactPreferencesMap.insert(std::make_pair(address, pref));
+}
+
 void Kleo::KeyResolver::saveContactPreference(const QString &email, const MessageComposer::ContactPreference &pref) const
 {
     d->mContactPreferencesMap.insert(std::make_pair(email, pref));
