@@ -6,23 +6,21 @@
 */
 
 #include "messagehelper.h"
-#include "utils/util.h"
 #include "settings/messagecomposersettings.h"
 
 #include "MessageCore/MailingList"
 #include "MessageCore/StringUtil"
 
+#include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
+#include <KMime/DateFormatter>
+#include <KMime/MDN>
 #include <KMime/Message>
-#include <kmime/kmime_mdn.h>
-#include <kmime/kmime_dateformatter.h>
-#include <kmime/kmime_headers.h>
-#include <kidentitymanagement/identitymanager.h>
-#include <kidentitymanagement/identity.h>
-#include "messagecomposer_debug.h"
 
 using namespace MessageCore;
 
-namespace MessageHelper {
+namespace MessageHelper
+{
 void initHeader(const KMime::Message::Ptr &message, const KIdentityManagement::IdentityManager *identMan, uint id)
 {
     applyIdentity(message, identMan, id);
@@ -34,19 +32,23 @@ void initHeader(const KMime::Message::Ptr &message, const KIdentityManagement::I
     message->contentType()->setMimeType("text/plain");
 }
 
-void initFromMessage(const KMime::Message::Ptr &msg, const KMime::Message::Ptr &origMsg, KIdentityManagement::IdentityManager *identMan, uint id, bool idHeaders)
+void initFromMessage(const KMime::Message::Ptr &msg,
+                     const KMime::Message::Ptr &origMsg,
+                     KIdentityManagement::IdentityManager *identMan,
+                     uint id,
+                     bool idHeaders)
 {
     if (idHeaders) {
         MessageHelper::initHeader(msg, identMan, id);
     } else {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Identity");
+        auto header = new KMime::Headers::Generic("X-KMail-Identity");
         header->fromUnicodeString(QString::number(id), "utf-8");
         msg->setHeader(header);
     }
 
     if (auto hdr = origMsg->headerByType("X-KMail-Transport")) {
         const QString transport = hdr->asUnicodeString();
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Transport");
+        auto header = new KMime::Headers::Generic("X-KMail-Transport");
         header->fromUnicodeString(transport, "utf-8");
         msg->setHeader(header);
     }
@@ -54,8 +56,7 @@ void initFromMessage(const KMime::Message::Ptr &msg, const KMime::Message::Ptr &
 
 void applyIdentity(const KMime::Message::Ptr &message, const KIdentityManagement::IdentityManager *identMan, uint id)
 {
-    const KIdentityManagement::Identity &ident
-        = identMan->identityForUoidOrDefault(id);
+    const KIdentityManagement::Identity &ident = identMan->identityForUoidOrDefault(id);
 
     if (ident.fullEmailAddr().isEmpty()) {
         message->removeHeader<KMime::Headers::From>();
@@ -90,7 +91,7 @@ void applyIdentity(const KMime::Message::Ptr &message, const KIdentityManagement
     if (ident.organization().isEmpty()) {
         message->removeHeader<KMime::Headers::Organization>();
     } else {
-        KMime::Headers::Organization *const organization = new KMime::Headers::Organization;
+        auto const organization = new KMime::Headers::Organization;
         organization->fromUnicodeString(ident.organization(), "utf-8");
         message->setHeader(organization);
     }
@@ -98,7 +99,7 @@ void applyIdentity(const KMime::Message::Ptr &message, const KIdentityManagement
     if (ident.isDefault()) {
         message->removeHeader("X-KMail-Identity");
     } else {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Identity");
+        auto header = new KMime::Headers::Generic("X-KMail-Identity");
         header->fromUnicodeString(QString::number(ident.uoid()), "utf-8");
         message->setHeader(header);
     }
@@ -106,7 +107,7 @@ void applyIdentity(const KMime::Message::Ptr &message, const KIdentityManagement
     if (ident.transport().isEmpty()) {
         message->removeHeader("X-KMail-Transport");
     } else {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Transport");
+        auto header = new KMime::Headers::Generic("X-KMail-Transport");
         header->fromUnicodeString(ident.transport(), "utf-8");
         message->setHeader(header);
     }
@@ -114,13 +115,13 @@ void applyIdentity(const KMime::Message::Ptr &message, const KIdentityManagement
     if (ident.fcc().isEmpty()) {
         message->removeHeader("X-KMail-Fcc");
     } else {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Fcc");
+        auto header = new KMime::Headers::Generic("X-KMail-Fcc");
         header->fromUnicodeString(ident.fcc(), "utf-8");
         message->setHeader(header);
     }
 
     if (ident.disabledFcc()) {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-FccDisabled");
+        auto header = new KMime::Headers::Generic("X-KMail-FccDisabled");
         header->fromUnicodeString(QStringLiteral("true"), "utf-8");
         message->setHeader(header);
     } else {
@@ -132,8 +133,9 @@ KMime::Types::AddrSpecList extractAddrSpecs(const KMime::Message::Ptr &msg, cons
 {
     KMime::Types::AddrSpecList result;
     if (auto hrd = msg->headerByType(header.constData())) {
-        KMime::Types::AddressList al
-            = MessageCore::StringUtil::splitAddressField(hrd->asUnicodeString().toUtf8());
+        // Don't use "asUnicodeString().toUtf8()" it removes \" from \"foo, bla\" <foo@kde.org> => send failed
+        // Bug 439218
+        KMime::Types::AddressList al = MessageCore::StringUtil::splitAddressField(hrd->as7BitString(false));
         KMime::Types::AddressList::const_iterator alend(al.constEnd());
         for (KMime::Types::AddressList::const_iterator ait = al.constBegin(); ait != alend; ++ait) {
             KMime::Types::MailboxList::const_iterator mitEnd((*ait).mailboxList.constEnd());
