@@ -1,29 +1,17 @@
 /*
-   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMAGESCALING_H
-#define IMAGESCALING_H
+#pragma once
 
 #include "messagecomposer_export.h"
 #include <QByteArray>
+#include <memory>
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class ImageScalingPrivate;
 /**
  * @brief The ImageScaling class
@@ -64,9 +52,8 @@ public:
     void setName(const QString &name);
 
     Q_REQUIRED_RESULT QString generateNewName();
+
 private:
-    ImageScalingPrivate *const d;
+    std::unique_ptr<ImageScalingPrivate> const d;
 };
 }
-
-#endif // IMAGESCALING_H
