@@ -9,8 +9,8 @@
 
 #include "distributionlistexpandjob.h"
 
-#include <akonadi/contact/contactgroupexpandjob.h>
-#include <akonadi/contact/contactgroupsearchjob.h>
+#include <Akonadi/ContactGroupExpandJob>
+#include <Akonadi/ContactGroupSearchJob>
 
 using namespace MessageComposer;
 
@@ -20,9 +20,7 @@ DistributionListExpandJob::DistributionListExpandJob(const QString &name, QObjec
 {
 }
 
-DistributionListExpandJob::~DistributionListExpandJob()
-{
-}
+DistributionListExpandJob::~DistributionListExpandJob() = default;
 
 void DistributionListExpandJob::start()
 {
