@@ -9,7 +9,6 @@
 
 #include "contentjobbase_p.h"
 
-#include "messagecomposer_debug.h"
 #include <KMime/Content>
 #include <KMime/KMimeMessage>
 using namespace MessageComposer;
@@ -32,9 +31,7 @@ TransparentJob::TransparentJob(QObject *parent)
 {
 }
 
-TransparentJob::~TransparentJob()
-{
-}
+TransparentJob::~TransparentJob() = default;
 
 void TransparentJob::setContent(KMime::Content *content)
 {
