@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PLUGINEDITORCONVERTERINITIALDATA_H
-#define PLUGINEDITORCONVERTERINITIALDATA_H
+#pragma once
 
 #include "messagecomposer_export.h"
 #include <KMime/Message>
-namespace MessageComposer {
+namespace MessageComposer
+{
 /**
  * @brief The PluginEditorConverterInitialData class
  * @author Laurent Montel <montel@kde.org>
@@ -30,4 +30,3 @@ private:
     bool mNewMessage = true;
 };
 }
-#endif // PLUGINEDITORCONVERTERINITIALDATA_H
