@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ PluginEditorConvertText::PluginEditorConvertText(QObject *parent)
 {
 }
 
-PluginEditorConvertText::~PluginEditorConvertText()
-{
-}
+PluginEditorConvertText::~PluginEditorConvertText() = default;
 
 bool PluginEditorConvertText::canWorkOnHtml() const
 {
