@@ -1,11 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "statusbarlabeltoggledstate.h"
 #include "messagecomposer_debug.h"
+#include <QMouseEvent>
 using namespace MessageComposer;
 StatusBarLabelToggledState::StatusBarLabelToggledState(QWidget *parent)
     : QLabel(parent)
@@ -13,13 +14,11 @@ StatusBarLabelToggledState::StatusBarLabelToggledState(QWidget *parent)
     setTextFormat(Qt::PlainText);
 }
 
-StatusBarLabelToggledState::~StatusBarLabelToggledState()
-{
-}
+StatusBarLabelToggledState::~StatusBarLabelToggledState() = default;
 
 void StatusBarLabelToggledState::setStateString(const QString &toggled, const QString &untoggled)
 {
-    if (toggled.isEmpty() || untoggled.isEmpty()) {
+    if (toggled.isEmpty() && untoggled.isEmpty()) {
         qCWarning(MESSAGECOMPOSER_LOG) << " State string is empty. Need to fix it";
     }
     mToggled = toggled;
@@ -52,6 +51,8 @@ void StatusBarLabelToggledState::updateLabel()
 
 void StatusBarLabelToggledState::mousePressEvent(QMouseEvent *ev)
 {
-    Q_UNUSED(ev);
-    setToggleMode(!mToggleMode);
+    Q_UNUSED(ev)
+    if (ev->button() == Qt::LeftButton) {
+        setToggleMode(!mToggleMode);
+    }
 }
