@@ -11,25 +11,25 @@
 #include "utils/util.h"
 #include "util_p.h"
 
-#include <QRegularExpression>
 #include "composer/composer.h"
 #include "job/singlepartjob.h"
+#include <QRegularExpression>
 
+#include <QTextBlock>
 #include <QTextCodec>
 #include <QTextDocument>
-#include <QTextBlock>
 
-#include <KCharsets>
 #include "messagecomposer_debug.h"
+#include <KEmailAddress>
 #include <KLocalizedString>
 #include <KMessageBox>
 
-#include <kmime/kmime_content.h>
-#include <kmime/kmime_headers.h>
-#include <MailTransportAkonadi/MessageQueueJob>
-#include <AkonadiCore/agentinstance.h>
-#include <AkonadiCore/agentinstancecreatejob.h>
-#include <AkonadiCore/agentmanager.h>
+#include <Akonadi/AgentInstance>
+#include <Akonadi/AgentInstanceCreateJob>
+#include <Akonadi/AgentManager>
+#include <Akonadi/MessageQueueJob>
+#include <KMime/Content>
+#include <KMime/Headers>
 #include <MessageCore/StringUtil>
 
 KMime::Content *setBodyAndCTE(QByteArray &encodedBody, KMime::Headers::ContentType *contentType, KMime::Content *ret)
@@ -49,49 +49,53 @@ KMime::Content *setBodyAndCTE(QByteArray &encodedBody, KMime::Headers::ContentTy
     return ret;
 }
 
-KMime::Content *MessageComposer::Util::composeHeadersAndBody(KMime::Content *orig, QByteArray encodedBody, Kleo::CryptoMessageFormat format, bool sign, const QByteArray &hashAlgo)
+KMime::Content *MessageComposer::Util::composeHeadersAndBody(KMime::Content *orig,
+                                                             QByteArray encodedBody,
+                                                             Kleo::CryptoMessageFormat format,
+                                                             bool sign,
+                                                             const QByteArray &hashAlgo)
 {
-    KMime::Content *result = new KMime::Content;
+    auto result = new KMime::Content;
 
     // called should have tested that the signing/encryption failed
     Q_ASSERT(!encodedBody.isEmpty());
 
-    if (!(format & Kleo::InlineOpenPGPFormat)) {    // make a MIME message
+    if (!(format & Kleo::InlineOpenPGPFormat)) { // make a MIME message
         qCDebug(MESSAGECOMPOSER_LOG) << "making MIME message, format:" << format;
         makeToplevelContentType(result, format, sign, hashAlgo);
 
-        if (makeMultiMime(format, sign)) {      // sign/enc PGPMime, sign SMIME
+        if (makeMultiMime(format, sign)) { // sign/enc PGPMime, sign SMIME
             const QByteArray boundary = KMime::multiPartBoundary();
             result->contentType()->setBoundary(boundary);
 
             result->assemble();
-            //qCDebug(MESSAGECOMPOSER_LOG) << "processed header:" << result->head();
+            // qCDebug(MESSAGECOMPOSER_LOG) << "processed header:" << result->head();
 
             // Build the encapsulated MIME parts.
             // Build a MIME part holding the code information
             // taking the body contents returned in ciphertext.
-            KMime::Content *code = new KMime::Content;
+            auto code = new KMime::Content;
             setNestedContentType(code, format, sign);
             setNestedContentDisposition(code, format, sign);
 
-            if (sign) {                           // sign PGPMime, sign SMIME
-                if (format & Kleo::AnySMIME) {      // sign SMIME
-                    auto ct = code->contentTransferEncoding(); //create
+            if (sign) { // sign PGPMime, sign SMIME
+                if (format & Kleo::AnySMIME) { // sign SMIME
+                    auto ct = code->contentTransferEncoding(); // create
                     ct->setEncoding(KMime::Headers::CEbase64);
                     ct->needToEncode();
                     code->setBody(encodedBody);
-                } else {                            // sign PGPMmime
+                } else { // sign PGPMmime
                     setBodyAndCTE(encodedBody, orig->contentType(), code);
                 }
                 result->addContent(orig);
                 result->addContent(code);
-            } else {                              // enc PGPMime
+            } else { // enc PGPMime
                 setBodyAndCTE(encodedBody, orig->contentType(), code);
 
                 // Build a MIME part holding the version information
                 // taking the body contents returned in
                 // structuring.data.bodyTextVersion.
-                KMime::Content *vers = new KMime::Content;
+                auto vers = new KMime::Content;
                 vers->contentType()->setMimeType("application/pgp-encrypted");
                 vers->contentDisposition()->setDisposition(KMime::Headers::CDattachment);
                 vers->contentTransferEncoding()->setEncoding(KMime::Headers::CE7Bit);
@@ -100,18 +104,18 @@ KMime::Content *MessageComposer::Util::composeHeadersAndBody(KMime::Content *ori
                 result->addContent(vers);
                 result->addContent(code);
             }
-        } else {                                //enc SMIME, sign/enc SMIMEOpaque
+        } else { // enc SMIME, sign/enc SMIMEOpaque
             result->contentTransferEncoding()->setEncoding(KMime::Headers::CEbase64);
-            auto ct = result->contentDisposition(); //Create
+            auto ct = result->contentDisposition(); // Create
             ct->setDisposition(KMime::Headers::CDattachment);
             ct->setFilename(QStringLiteral("smime.p7m"));
 
             result->assemble();
-            //qCDebug(MESSAGECOMPOSER_LOG) << "processed header:" << result->head();
+            // qCDebug(MESSAGECOMPOSER_LOG) << "processed header:" << result->head();
 
             result->setBody(encodedBody);
         }
-    } else {                                  // sign/enc PGPInline
+    } else { // sign/enc PGPInline
         result->setHead(orig->head());
         result->parse();
 
@@ -128,7 +132,7 @@ void MessageComposer::Util::makeToplevelContentType(KMime::Content *content, Kle
     default:
     case Kleo::InlineOpenPGPFormat:
     case Kleo::OpenPGPMIMEFormat: {
-        auto ct = content->contentType(); //Create
+        auto ct = content->contentType(); // Create
         if (sign) {
             ct->setMimeType(QByteArrayLiteral("multipart/signed"));
             ct->setParameter(QStringLiteral("protocol"), QStringLiteral("application/pgp-signature"));
@@ -141,7 +145,7 @@ void MessageComposer::Util::makeToplevelContentType(KMime::Content *content, Kle
         return;
     case Kleo::SMIMEFormat: {
         if (sign) {
-            auto ct = content->contentType(); //Create
+            auto ct = content->contentType(); // Create
             qCDebug(MESSAGECOMPOSER_LOG) << "setting headers for SMIME";
             ct->setMimeType(QByteArrayLiteral("multipart/signed"));
             ct->setParameter(QStringLiteral("protocol"), QStringLiteral("application/pkcs7-signature"));
@@ -156,7 +160,7 @@ void MessageComposer::Util::makeToplevelContentType(KMime::Content *content, Kle
     case Kleo::SMIMEOpaqueFormat:
 
         qCDebug(MESSAGECOMPOSER_LOG) << "setting headers for SMIME/opaque";
-        auto ct = content->contentType(); //Create
+        auto ct = content->contentType(); // Create
         ct->setMimeType(QByteArrayLiteral("application/pkcs7-mime"));
 
         if (sign) {
@@ -172,7 +176,7 @@ void MessageComposer::Util::setNestedContentType(KMime::Content *content, Kleo::
 {
     switch (format) {
     case Kleo::OpenPGPMIMEFormat: {
-        auto ct = content->contentType(); //Create
+        auto ct = content->contentType(); // Create
         if (sign) {
             ct->setMimeType(QByteArrayLiteral("application/pgp-signature"));
             ct->setParameter(QStringLiteral("name"), QStringLiteral("signature.asc"));
@@ -184,7 +188,7 @@ void MessageComposer::Util::setNestedContentType(KMime::Content *content, Kleo::
         return;
     case Kleo::SMIMEFormat: {
         if (sign) {
-            auto ct = content->contentType(); //Create
+            auto ct = content->contentType(); // Create
             ct->setMimeType(QByteArrayLiteral("application/pkcs7-signature"));
             ct->setParameter(QStringLiteral("name"), QStringLiteral("smime.p7s"));
             return;
@@ -194,8 +198,7 @@ void MessageComposer::Util::setNestedContentType(KMime::Content *content, Kleo::
     // fall through:
     default:
     case Kleo::InlineOpenPGPFormat:
-    case Kleo::SMIMEOpaqueFormat:
-        ;
+    case Kleo::SMIMEOpaqueFormat:;
     }
 }
 
@@ -221,7 +224,7 @@ bool MessageComposer::Util::makeMultiMime(Kleo::CryptoMessageFormat format, bool
     case Kleo::OpenPGPMIMEFormat:
         return true;
     case Kleo::SMIMEFormat:
-        return sign;                             // only on sign - there's no mp/encrypted for S/MIME
+        return sign; // only on sign - there's no mp/encrypted for S/MIME
     }
 }
 
@@ -230,7 +233,7 @@ QByteArray MessageComposer::Util::selectCharset(const QVector<QByteArray> &chars
     for (const QByteArray &name : charsets) {
         // We use KCharsets::codecForName() instead of QTextCodec::codecForName() here, because
         // the former knows us-ascii is latin1.
-        QTextCodec *codec = KCharsets::charsets()->codecForName(QString::fromLatin1(name));
+        QTextCodec *codec = QTextCodec::codecForName(name);
         if (!codec) {
             qCWarning(MESSAGECOMPOSER_LOG) << "Could not get text codec for charset" << name;
             continue;
@@ -245,15 +248,16 @@ QByteArray MessageComposer::Util::selectCharset(const QVector<QByteArray> &chars
         }
     }
     qCDebug(MESSAGECOMPOSER_LOG) << "No appropriate charset found.";
-    return QByteArray();
+    return {};
 }
 
 QStringList MessageComposer::Util::AttachmentKeywords()
 {
     return i18nc(
-        "comma-separated list of keywords that are used to detect whether "
-        "the user forgot to attach his attachment. Do not add space between words.",
-        "attachment,attached").split(QLatin1Char(','));
+               "comma-separated list of keywords that are used to detect whether "
+               "the user forgot to attach his attachment. Do not add space between words.",
+               "attachment,attached")
+        .split(QLatin1Char(','));
 }
 
 QString MessageComposer::Util::cleanedUpHeaderString(const QString &s)
@@ -265,16 +269,16 @@ QString MessageComposer::Util::cleanedUpHeaderString(const QString &s)
     return res.trimmed();
 }
 
-void MessageComposer::Util::addSendReplyForwardAction(const KMime::Message::Ptr &message, MailTransport::MessageQueueJob *qjob)
+void MessageComposer::Util::addSendReplyForwardAction(const KMime::Message::Ptr &message, Akonadi::MessageQueueJob *qjob)
 {
     QVector<Akonadi::Item::Id> originalMessageId;
     QVector<Akonadi::MessageStatus> linkStatus;
     if (MessageComposer::Util::getLinkInformation(message, originalMessageId, linkStatus)) {
-        for (Akonadi::Item::Id id : qAsConst(originalMessageId)) {
+        for (Akonadi::Item::Id id : std::as_const(originalMessageId)) {
             if (linkStatus.first() == Akonadi::MessageStatus::statusReplied()) {
-                qjob->sentActionAttribute().addAction(MailTransport::SentActionAttribute::Action::MarkAsReplied, QVariant(id));
+                qjob->sentActionAttribute().addAction(Akonadi::SentActionAttribute::Action::MarkAsReplied, QVariant(id));
             } else if (linkStatus.first() == Akonadi::MessageStatus::statusForwarded()) {
-                qjob->sentActionAttribute().addAction(MailTransport::SentActionAttribute::Action::MarkAsForwarded, QVariant(id));
+                qjob->sentActionAttribute().addAction(Akonadi::SentActionAttribute::Action::MarkAsForwarded, QVariant(id));
             }
         }
     }
@@ -284,12 +288,18 @@ bool MessageComposer::Util::sendMailDispatcherIsOnline(QWidget *parent)
 {
     Akonadi::AgentInstance instance = Akonadi::AgentManager::self()->instance(QStringLiteral("akonadi_maildispatcher_agent"));
     if (!instance.isValid()) {
-        const int rc = KMessageBox::warningYesNo(parent, i18n("The mail dispatcher is not set up, so mails cannot be sent. Do you want to create a mail dispatcher?"),
-                                                 i18n("No mail dispatcher."), KStandardGuiItem::yes(), KStandardGuiItem::no(), QStringLiteral("no_maildispatcher"));
-        if (rc == KMessageBox::Yes) {
+        const int rc =
+            KMessageBox::warningTwoActions(parent,
+                                           i18n("The mail dispatcher is not set up, so mails cannot be sent. Do you want to create a mail dispatcher?"),
+                                           i18n("No mail dispatcher."),
+
+                                           KGuiItem(i18nc("@action:button", "Create Mail Dispatcher"), QIcon::fromTheme(QStringLiteral("mail-folder-outbox"))),
+                                           KStandardGuiItem::cancel(),
+                                           QStringLiteral("no_maildispatcher"));
+        if (rc == KMessageBox::ButtonCode::PrimaryAction) {
             const Akonadi::AgentType type = Akonadi::AgentManager::self()->type(QStringLiteral("akonadi_maildispatcher_agent"));
             Q_ASSERT(type.isValid());
-            Akonadi::AgentInstanceCreateJob *job = new Akonadi::AgentInstanceCreateJob(type); // async. We'll have to try again later.
+            auto job = new Akonadi::AgentInstanceCreateJob(type); // async. We'll have to try again later.
             job->start();
         }
         return false;
@@ -297,9 +307,13 @@ bool MessageComposer::Util::sendMailDispatcherIsOnline(QWidget *parent)
     if (instance.isOnline()) {
         return true;
     } else {
-        const int rc = KMessageBox::warningYesNo(parent, i18n("The mail dispatcher is offline, so mails cannot be sent. Do you want to make it online?"),
-                                                 i18n("Mail dispatcher offline."), KStandardGuiItem::yes(), KStandardGuiItem::no(), QStringLiteral("maildispatcher_put_online"));
-        if (rc == KMessageBox::Yes) {
+        const int rc = KMessageBox::warningTwoActions(parent,
+                                                      i18n("The mail dispatcher is offline, so mails cannot be sent. Do you want to make it online?"),
+                                                      i18n("Mail dispatcher offline."),
+                                                      KGuiItem(i18nc("@action:button", "Set Online"), QIcon::fromTheme(QStringLiteral("user-online"))),
+                                                      KStandardGuiItem::cancel(),
+                                                      QStringLiteral("maildispatcher_put_online"));
+        if (rc == KMessageBox::ButtonCode::PrimaryAction) {
             instance.setIsOnline(true);
             return true;
         }
@@ -307,29 +321,20 @@ bool MessageComposer::Util::sendMailDispatcherIsOnline(QWidget *parent)
     return false;
 }
 
-void MessageComposer::Util::removeNotNecessaryHeaders(const KMime::Message::Ptr &msg)
-{
-    msg->removeHeader("X-KMail-SignatureActionEnabled");
-    msg->removeHeader("X-KMail-EncryptActionEnabled");
-    msg->removeHeader("X-KMail-CryptoMessageFormat");
-}
-
 KMime::Content *MessageComposer::Util::findTypeInMessage(KMime::Content *data, const QByteArray &mimeType, const QByteArray &subType)
 {
     if (!data->contentType()->isEmpty()) {
         if (mimeType.isEmpty() || subType.isEmpty()) {
             return data;
         }
-        if ((mimeType == data->contentType()->mediaType())
-            && (subType == data->contentType()->subType())) {
+        if ((mimeType == data->contentType()->mediaType()) && (subType == data->contentType(false)->subType())) {
             return data;
         }
     }
 
-    foreach (auto child, data->contents()) {
-        if ((!child->contentType()->isEmpty())
-            && (mimeType == child->contentType()->mimeType())
-            && (subType == child->contentType()->subType())) {
+    const auto contents = data->contents();
+    for (auto child : contents) {
+        if ((!child->contentType()->isEmpty()) && (mimeType == child->contentType()->mimeType()) && (subType == child->contentType()->subType())) {
             return child;
         }
         auto ret = findTypeInMessage(child, mimeType, subType);
@@ -367,7 +372,7 @@ void MessageComposer::Util::addLinkInformation(const KMime::Message::Ptr &msg, A
         type += QLatin1String("forward");
     }
 
-    KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Link-Message");
+    auto header = new KMime::Headers::Generic("X-KMail-Link-Message");
     header->fromUnicodeString(message, "utf-8");
     msg->setHeader(header);
 
@@ -384,16 +389,8 @@ bool MessageComposer::Util::getLinkInformation(const KMime::Message::Ptr &msg, Q
         return false;
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList messages = hrdLinkMsg->asUnicodeString().split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
     const QStringList messages = hrdLinkMsg->asUnicodeString().split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList types = hrdLinkType->asUnicodeString().split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
     const QStringList types = hrdLinkType->asUnicodeString().split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
 
     if (messages.isEmpty() || types.isEmpty()) {
         return false;
@@ -423,7 +420,7 @@ KMime::Message::Ptr MessageComposer::Util::message(const Akonadi::Item &item)
 {
     if (!item.hasPayload<KMime::Message::Ptr>()) {
         qCWarning(MESSAGECOMPOSER_LOG) << "Payload is not a MessagePtr!";
-        return KMime::Message::Ptr();
+        return {};
     }
 
     return item.payload<KMime::Message::Ptr>();
@@ -436,9 +433,8 @@ bool MessageComposer::Util::hasMissingAttachments(const QStringList &attachmentK
     }
     QStringList attachWordsList = attachmentKeywords;
 
-    QRegularExpression rx(QLatin1String("\\b")
-                          +attachWordsList.join(QLatin1String("\\b|\\b"))
-                          +QLatin1String("\\b"), QRegularExpression::CaseInsensitiveOption);
+    QRegularExpression rx(QLatin1String("\\b") + attachWordsList.join(QLatin1String("\\b|\\b")) + QLatin1String("\\b"),
+                          QRegularExpression::CaseInsensitiveOption);
 
     // check whether the subject contains one of the attachment key words
     // unless the message is a reply or a forwarded message
@@ -451,8 +447,7 @@ bool MessageComposer::Util::hasMissingAttachments(const QStringList &attachmentK
         QTextBlock end(doc->end());
         for (QTextBlock it = doc->begin(); it != end; it = it.next()) {
             const QString line = it.text();
-            gotMatch = (!quotationRx.match(line).hasMatch())
-                       && (rx.match(line).hasMatch());
+            gotMatch = (!quotationRx.match(line).hasMatch()) && (rx.match(line).hasMatch());
             if (gotMatch) {
                 break;
             }
@@ -464,3 +459,39 @@ bool MessageComposer::Util::hasMissingAttachments(const QStringList &attachmentK
     }
     return true;
 }
+
+static QStringList encodeIdn(const QStringList &emails)
+{
+    QStringList encoded;
+    encoded.reserve(emails.count());
+    for (const QString &email : emails) {
+        encoded << KEmailAddress::normalizeAddressesAndEncodeIdn(email);
+    }
+    return encoded;
+}
+
+QStringList MessageComposer::Util::cleanEmailList(const QStringList &emails)
+{
+    QStringList clean;
+    clean.reserve(emails.count());
+    for (const QString &email : emails) {
+        clean << KEmailAddress::extractEmailAddress(email);
+    }
+    return clean;
+}
+
+QStringList MessageComposer::Util::cleanUpEmailListAndEncoding(const QStringList &emails)
+{
+    return cleanEmailList(encodeIdn(emails));
+}
+
+void MessageComposer::Util::addCustomHeaders(const KMime::Message::Ptr &message, const QMap<QByteArray, QString> &custom)
+{
+    QMapIterator<QByteArray, QString> customHeader(custom);
+    while (customHeader.hasNext()) {
+        customHeader.next();
+        auto header = new KMime::Headers::Generic(customHeader.key().constData());
+        header->fromUnicodeString(customHeader.value(), "utf-8");
+        message->setHeader(header);
+    }
+}
