@@ -10,7 +10,7 @@
 
 #include "messagecomposer_export.h"
 #include <Akonadi/Item>
-#include <Akonadi/KMime/MessageStatus>
+#include <Akonadi/MessageStatus>
 #include <KMime/Message>
 #include <Libkleo/Enum>
 
@@ -80,4 +80,3 @@ Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT QStringList cleanUpEmailListAndEncoding
 MESSAGECOMPOSER_EXPORT void addCustomHeaders(const KMime::Message::Ptr &message, const QMap<QByteArray, QString> &customHeader);
 }
 }
-
