@@ -8,22 +8,21 @@
 
 #include "attachmentcompressjob.h"
 
-#include "messagecore_debug.h"
 #include <KLocalizedString>
 #include <KZip>
 
 #include <QBuffer>
-#include <QTimer>
-#include <QSharedPointer>
 #include <QDateTime>
+#include <QSharedPointer>
+#include <QTimer>
 
 using namespace MessageCore;
 static const mode_t archivePerms = S_IFREG | 0644;
 
-class Q_DECL_HIDDEN MessageCore::AttachmentCompressJob::Private
+class MessageCore::AttachmentCompressJob::AttachmentCompressJobPrivate
 {
 public:
-    Private(AttachmentCompressJob *qq);
+    AttachmentCompressJobPrivate(AttachmentCompressJob *qq);
 
     void doStart(); // slot
 
@@ -33,12 +32,12 @@ public:
     bool mCompressedPartLarger = false;
 };
 
-AttachmentCompressJob::Private::Private(AttachmentCompressJob *qq)
+AttachmentCompressJob::AttachmentCompressJobPrivate::AttachmentCompressJobPrivate(AttachmentCompressJob *qq)
     : q(qq)
 {
 }
 
-void AttachmentCompressJob::Private::doStart()
+void AttachmentCompressJob::AttachmentCompressJobPrivate::doStart()
 {
     Q_ASSERT(mOriginalPart);
     const QByteArray decoded = mOriginalPart->data();
@@ -56,9 +55,7 @@ void AttachmentCompressJob::Private::doStart()
     // Compress.
     zip.setCompression(KZip::DeflateCompression);
     QDateTime zipTime = QDateTime::currentDateTime();
-    if (!zip.writeFile(mOriginalPart->name(), decoded, archivePerms,
-                       QString(/*user*/), QString(/*group*/),
-                       zipTime, zipTime, zipTime)) {
+    if (!zip.writeFile(mOriginalPart->name(), decoded, archivePerms, QString(/*user*/), QString(/*group*/), zipTime, zipTime, zipTime)) {
         q->setError(KJob::UserDefinedError);
         q->setErrorText(i18n("Could not compress the attachment."));
         q->emitResult();
@@ -70,7 +67,7 @@ void AttachmentCompressJob::Private::doStart()
     // Create new part.
     Q_ASSERT(mCompressedPart == nullptr);
     mCompressedPart = AttachmentPart::Ptr(new AttachmentPart);
-    mCompressedPart->setName(mOriginalPart->name() + QLatin1String(".zip"));     // TODO not sure name should be .zipped too
+    mCompressedPart->setName(mOriginalPart->name() + QLatin1String(".zip")); // TODO not sure name should be .zipped too
     mCompressedPart->setFileName(mOriginalPart->fileName() + QLatin1String(".zip"));
     mCompressedPart->setDescription(mOriginalPart->description());
     mCompressedPart->setInline(mOriginalPart->isInline());
@@ -86,15 +83,12 @@ void AttachmentCompressJob::Private::doStart()
 
 AttachmentCompressJob::AttachmentCompressJob(const AttachmentPart::Ptr &part, QObject *parent)
     : KJob(parent)
-    , d(new Private(this))
+    , d(new AttachmentCompressJobPrivate(this))
 {
     d->mOriginalPart = part;
 }
 
-AttachmentCompressJob::~AttachmentCompressJob()
-{
-    delete d;
-}
+AttachmentCompressJob::~AttachmentCompressJob() = default;
 
 void AttachmentCompressJob::start()
 {
