@@ -1,34 +1,22 @@
 /*
-  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGECORE_ATTACHMENTFROMMIMECONTENTJOB_H
-#define MESSAGECORE_ATTACHMENTFROMMIMECONTENTJOB_H
+#pragma once
 
 #include "messagecore_private_export.h"
 
 #include "attachmentloadjob.h"
-
-namespace KMime {
+#include <memory>
+namespace KMime
+{
 class Content;
 }
 
-namespace MessageCore {
+namespace MessageCore
+{
 /**
  * @short A job to load an attachment from a mime content.
  *
@@ -67,10 +55,8 @@ protected Q_SLOTS:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    class AttachmentFromMimeContentJobPrivate;
+    std::unique_ptr<AttachmentFromMimeContentJobPrivate> const d;
     //@endcond
 };
 }
-
-#endif
