@@ -10,6 +10,7 @@
 #include "aggregation.h"
 #include "messagelist_debug.h"
 
+#include <QDebug>
 #include <QDir>
 #include <QFile>
 #include <QStandardPaths>
@@ -23,9 +24,23 @@ struct CacheHeader {
     Aggregation::Grouping grouping;
     Aggregation::Threading threading;
     Aggregation::ThreadLeader threadLeader;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     int cacheSize;
+#else
+    qsizetype cacheSize;
+#endif
 };
 
+QDebug operator<<(QDebug d, const CacheHeader &t)
+{
+    d << " grouping " << t.grouping;
+    d << " threading " << t.threading;
+    d << " threadLeader " << t.threadLeader;
+    d << " grouping " << t.grouping;
+    d << " cacheSize " << t.cacheSize;
+    return d;
+}
+
 QDataStream &operator<<(QDataStream &stream, const CacheHeader &header)
 {
     return stream << header.version << (qint8)header.grouping << (qint8)header.threading << (qint8)header.threadLeader << header.cacheSize;
@@ -37,9 +52,7 @@ QDataStream &operator>>(QDataStream &stream, CacheHeader &header)
 }
 }
 
-ThreadingCache::ThreadingCache()
-{
-}
+ThreadingCache::ThreadingCache() = default;
 
 ThreadingCache::~ThreadingCache()
 {
@@ -69,6 +82,11 @@ void ThreadingCache::load(const QString &id, const Aggregation *aggregation)
     mGrouping = aggregation->grouping();
     mEnabled = true;
 
+    if (id.isEmpty()) {
+        qCDebug(MESSAGELIST_LOG) << "Invalid collection: id is empty";
+        return;
+    }
+
     const QString cacheFileName =
         QStandardPaths::locate(QStandardPaths::CacheLocation, QStringLiteral("messagelist/threading/%1").arg(id), QStandardPaths::LocateFile);
     if (cacheFileName.isEmpty()) {
@@ -84,6 +102,7 @@ void ThreadingCache::load(const QString &id, const Aggregation *aggregation)
     }
 
     QDataStream stream(&cacheFile);
+    stream.setVersion(QDataStream::Qt_5_15);
     CacheHeader cacheHeader = {};
     stream >> cacheHeader;
 
@@ -102,7 +121,6 @@ void ThreadingCache::load(const QString &id, const Aggregation *aggregation)
         cacheFile.remove();
         return;
     }
-
     mItemCache.reserve(cacheHeader.cacheSize);
     mParentCache.reserve(cacheHeader.cacheSize);
 
@@ -147,6 +165,7 @@ void ThreadingCache::save()
     qCDebug(MESSAGELIST_LOG) << "Saving threading cache to" << cacheFile.fileName();
 
     QDataStream stream(&cacheFile);
+    stream.setVersion(QDataStream::Qt_5_15);
     CacheHeader cacheHeader{1, // version
                             mGrouping,
                             mThreading,
