@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,7 +8,7 @@
 #pragma once
 
 #include "messagelist_export.h"
-#include <Akonadi/KMime/MessageStatus>
+#include <Akonadi/MessageStatus>
 #include <QWidget>
 
 class QComboBox;
@@ -73,9 +73,9 @@ Q_SIGNALS:
 protected:
     bool eventFilter(QObject *object, QEvent *e) override;
 private Q_SLOTS:
-    void slotSearchEditTextEdited(const QString &text);
-    void slotClearButtonClicked();
-    void slotFilterActionChanged(const QVector<Akonadi::MessageStatus> &lst);
+    MESSAGELIST_NO_EXPORT void slotSearchEditTextEdited(const QString &text);
+    MESSAGELIST_NO_EXPORT void slotClearButtonClicked();
+    MESSAGELIST_NO_EXPORT void slotFilterActionChanged(const QVector<Akonadi::MessageStatus> &lst);
 
 private:
     SearchLineStatus *const mSearchEdit;
