@@ -1,51 +1,55 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "searchlinestatus.h"
+#include "configurefiltersdialog.h"
+#include "core/filtersavedmanager.h"
+#include "filtersavedmenu.h"
 #include "messagelist_debug.h"
+#include <KStatefulBrush>
 
-#include <KLocalizedString>
-#include <QAction>
-#include <QStandardPaths>
-#include <QMenu>
+#include <KColorScheme>
 #include <KIconEngine>
 #include <KIconLoader>
-#include <QWidgetAction>
-#include <QPushButton>
+#include <KLocalizedString>
+#include <QAbstractItemView>
+#include <QAction>
+#include <QActionGroup>
 #include <QCompleter>
 #include <QContextMenuEvent>
+#include <QMenu>
+#include <QPushButton>
+#include <QStandardPaths>
 #include <QStringListModel>
-#include <QAbstractItemView>
-#include <KColorScheme>
+#include <QWidgetAction>
 
 static const char qLineEditclearButtonActionNameC[] = "_q_qlineeditclearaction";
 #define MAX_COMPLETION_ITEMS 20
 using namespace MessageList::Core;
 SearchLineStatus::SearchLineStatus(QWidget *parent)
     : QLineEdit(parent)
+    , mCompleter(new QCompleter(this))
+    , mCompleterListModel(new QStringListModel(this))
 {
-    mCompleter = new QCompleter(this);
-    mCompleterListModel = new QStringListModel(this);
     mCompleter->setModel(mCompleterListModel);
     setCompleter(mCompleter);
 
     setClearButtonEnabled(true);
     initializeActions();
     createMenuSearch();
-    QAction *act = findChild<QAction *>(QLatin1String(qLineEditclearButtonActionNameC));
+    auto act = findChild<QAction *>(QLatin1String(qLineEditclearButtonActionNameC));
     if (act) {
         connect(act, &QAction::triggered, this, &SearchLineStatus::slotClear);
     } else {
         qCWarning(MESSAGELIST_LOG) << "Clear button name was changed ! Please verify qt code";
     }
+    connect(FilterSavedManager::self(), &FilterSavedManager::activateFilter, this, &SearchLineStatus::slotActivateFilter);
 }
 
-SearchLineStatus::~SearchLineStatus()
-{
-}
+SearchLineStatus::~SearchLineStatus() = default;
 
 void SearchLineStatus::keyPressEvent(QKeyEvent *e)
 {
@@ -71,8 +75,7 @@ void SearchLineStatus::updateLockAction()
 {
     if (mLocked) {
         mLockAction->setIcon(QIcon::fromTheme(QStringLiteral("object-locked")));
-        mLockAction->setToolTip(i18nc("@info:tooltip",
-                                      "Prevent the quick search field from being cleared when changing folders"));
+        mLockAction->setToolTip(i18nc("@info:tooltip", "Prevent the quick search field from being cleared when changing folders"));
     } else {
         mLockAction->setIcon(QIcon::fromTheme(QStringLiteral("object-unlocked")));
         mLockAction->setToolTip(i18nc("@info:tooltip", "Clear the quick search field when changing folders"));
@@ -94,11 +97,10 @@ bool SearchLineStatus::locked() const
 void SearchLineStatus::initializeActions()
 {
     mLockAction = addAction(QIcon::fromTheme(QStringLiteral("object-locked")), QLineEdit::TrailingPosition);
-    mLockAction->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "Toggle this button if you want to keep your quick search "
-              "locked when moving to other folders or when narrowing the search "
-              "by message status."));
+    mLockAction->setWhatsThis(i18nc("@info:whatsthis",
+                                    "Toggle this button if you want to keep your quick search "
+                                    "locked when moving to other folders or when narrowing the search "
+                                    "by message status."));
 
     connect(mLockAction, &QAction::triggered, this, &SearchLineStatus::slotToggledLockAction);
     updateLockAction();
@@ -108,8 +110,31 @@ void SearchLineStatus::initializeActions()
     mWithoutFilter = QIcon::fromTheme(QStringLiteral("view-filter"));
     mFiltersAction = addAction(mWithoutFilter, QLineEdit::LeadingPosition);
     mFiltersAction->setToolTip(i18n("Filter Mails by Status"));
-
     connect(mFiltersAction, &QAction::triggered, this, &SearchLineStatus::showMenu);
+
+    mSaveFilterAction = addAction(QIcon::fromTheme(QStringLiteral("edit-find")), QLineEdit::LeadingPosition);
+    mSaveFilterAction->setToolTip(i18n("Saved Filter"));
+    mFilterSavedMenu = new FilterSavedMenu(this);
+    mSaveFilterAction->setMenu(mFilterSavedMenu);
+    connect(mSaveFilterAction, &QAction::triggered, this, &SearchLineStatus::showSavedFiltersMenu);
+    connect(mFilterSavedMenu, &FilterSavedMenu::saveFilter, this, &SearchLineStatus::saveFilter);
+    connect(mFilterSavedMenu, &FilterSavedMenu::configureFilters, this, &SearchLineStatus::slotConfigureFilters);
+}
+
+void SearchLineStatus::slotActivateFilter(const QString &identifier)
+{
+    Filter *f = FilterSavedManager::self()->loadFilter(identifier);
+    if (f) {
+        Q_EMIT activateFilter(f);
+    } else {
+        qCWarning(MESSAGELIST_LOG) << "Impossible to load Filter from identifier :" << identifier;
+    }
+}
+
+void SearchLineStatus::slotConfigureFilters()
+{
+    ConfigureFiltersDialog dlg(this);
+    dlg.exec();
 }
 
 void SearchLineStatus::slotToggledLockAction()
@@ -122,10 +147,10 @@ void SearchLineStatus::updateFilters()
 {
     QVector<Akonadi::MessageStatus> lstStatus;
 
-    for (QAction *act : qAsConst(mFilterListActions)) {
+    for (QAction *act : std::as_const(mFilterListActions)) {
         if (act->isChecked()) {
             Akonadi::MessageStatus status;
-            status.fromQInt32(static_cast< qint32 >(act->data().toInt()));
+            status.fromQInt32(static_cast<qint32>(act->data().toInt()));
             lstStatus.append(status);
         }
     }
@@ -134,6 +159,11 @@ void SearchLineStatus::updateFilters()
     updateFilterActionIcon();
 }
 
+void SearchLineStatus::showSavedFiltersMenu()
+{
+    mFilterSavedMenu->exec(mapToGlobal(QPoint(0, height())));
+}
+
 void SearchLineStatus::showMenu()
 {
     if (mFilterMenu->exec(mapToGlobal(QPoint(0, height())))) {
@@ -143,7 +173,7 @@ void SearchLineStatus::showMenu()
 
 void SearchLineStatus::clearFilterAction()
 {
-    for (QAction *act : qAsConst(mFilterListActions)) {
+    for (QAction *act : std::as_const(mFilterListActions)) {
         act->setChecked(false);
     }
     mHasFilter = false;
@@ -152,7 +182,7 @@ void SearchLineStatus::clearFilterAction()
 
 void SearchLineStatus::createFilterAction(const QIcon &icon, const QString &text, int value)
 {
-    QAction *act = new QAction(icon, text, this);
+    auto act = new QAction(icon, text, this);
     act->setCheckable(true);
     act->setData(value);
     mFilterMenu->addAction(act);
@@ -165,7 +195,7 @@ void SearchLineStatus::updateFilterActionIcon()
     if (mColorName.isEmpty()) {
         const KColorScheme::BackgroundRole bgColorScheme(KColorScheme::PositiveBackground);
         KStatefulBrush bgBrush(KColorScheme::View, bgColorScheme);
-        mColorName = bgBrush.brush(this).color().name();
+        mColorName = bgBrush.brush(palette()).color().name();
     }
     setStyleSheet(mHasFilter ? QStringLiteral("QLineEdit{ background-color:%1 }").arg(mColorName) : QString());
 }
@@ -181,13 +211,14 @@ void SearchLineStatus::createMenuSearch()
 {
     mFilterMenu = new QMenu(this);
     mFilterMenu->setObjectName(QStringLiteral("filtermenu"));
-    QWidgetAction *clearWidgetAction = new QWidgetAction(mFilterMenu);
-    QPushButton *clearFilterButton = new QPushButton(i18n("Clear Filter"), mFilterMenu);
+    auto clearWidgetAction = new QWidgetAction(mFilterMenu);
+    auto clearFilterButton = new QPushButton(i18n("Clear Filter"), mFilterMenu);
     connect(clearFilterButton, &QPushButton::clicked, this, &SearchLineStatus::clearFilterButtonClicked);
 
     clearWidgetAction->setDefaultWidget(clearFilterButton);
     mFilterMenu->addAction(clearWidgetAction);
-    createFilterAction(QIcon::fromTheme(QStringLiteral("mail-unread")), i18nc("@action:inmenu Status of a message", "Unread"),
+    createFilterAction(QIcon::fromTheme(QStringLiteral("mail-unread")),
+                       i18nc("@action:inmenu Status of a message", "Unread"),
                        Akonadi::MessageStatus::statusUnread().toQInt32());
 
     createFilterAction(QIcon::fromTheme(QStringLiteral("mail-replied")),
@@ -206,11 +237,11 @@ void SearchLineStatus::createMenuSearch()
                        i18nc("@action:inmenu Status of a message", "Action Item"),
                        Akonadi::MessageStatus::statusToAct().toQInt32());
 
-    createFilterAction(QIcon::fromTheme(QStringLiteral("mail-thread-watch.png")),
+    createFilterAction(QIcon::fromTheme(QStringLiteral("mail-thread-watch")),
                        i18nc("@action:inmenu Status of a message", "Watched"),
                        Akonadi::MessageStatus::statusWatched().toQInt32());
 
-    createFilterAction(QIcon::fromTheme(QStringLiteral("mail-thread-ignored.png")),
+    createFilterAction(QIcon::fromTheme(QStringLiteral("mail-thread-ignored")),
                        i18nc("@action:inmenu Status of a message", "Ignored"),
                        Akonadi::MessageStatus::statusIgnored().toQInt32());
 
@@ -235,7 +266,7 @@ void SearchLineStatus::createMenuSearch()
 void SearchLineStatus::createFilterByAction()
 {
     mFilterMenu->addSeparator();
-    QActionGroup *grp = new QActionGroup(mFilterMenu);
+    auto grp = new QActionGroup(mFilterMenu);
 
     mSearchEveryWhereAction = new QAction(i18n("Full Message"), mFilterMenu);
     mSearchEveryWhereAction->setCheckable(true);
@@ -319,9 +350,39 @@ QuickSearchLine::SearchOptions SearchLineStatus::searchOptions() const
     return searchOptions;
 }
 
+void SearchLineStatus::setSearchOptions(QuickSearchLine::SearchOptions opts)
+{
+    mSearchEveryWhereAction->setChecked(opts & QuickSearchLine::SearchEveryWhere);
+    mSearchAgainstBodyAction->setChecked(opts & QuickSearchLine::SearchAgainstBody);
+    mSearchAgainstSubjectAction->setChecked(opts & QuickSearchLine::SearchAgainstSubject);
+    mSearchAgainstBccAction->setChecked(opts & QuickSearchLine::SearchAgainstBcc);
+    if (mContainsOutboundMessages) {
+        mSearchAgainstFromOrToAction->setChecked(opts & QuickSearchLine::SearchAgainstTo);
+    } else {
+        mSearchAgainstFromOrToAction->setChecked(opts & QuickSearchLine::SearchAgainstFrom);
+    }
+}
+
+void SearchLineStatus::setFilterMessageStatus(const QVector<Akonadi::MessageStatus> &newLstStatus)
+{
+    clearFilterAction();
+    clearFilterByAction();
+    // TODO unchecked all checkbox
+    for (const Akonadi::MessageStatus &status : newLstStatus) {
+        for (QAction *act : std::as_const(mFilterListActions)) {
+            if (static_cast<qint32>(act->data().toInt()) == status.toQInt32()) {
+                act->setChecked(true);
+                mHasFilter = true;
+                break;
+            }
+        }
+    }
+    updateFilterActionIcon();
+}
+
 void SearchLineStatus::slotFilterActionClicked(QAction *act)
 {
-    Q_UNUSED(act);
+    Q_UNUSED(act)
     Q_EMIT searchOptionChanged();
 }
 
