@@ -1,22 +1,24 @@
 /*
   This file is part of KMail, the KDE mail client.
-  SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGELISTUTIL_H
-#define MESSAGELISTUTIL_H
+#pragma once
 
-#include <messagelist_export.h>
-#include <QString>
+#include "messagelist_export.h"
 #include <QColor>
+#include <QString>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Item;
 }
-namespace MessageList {
-namespace Util {
+namespace MessageList
+{
+namespace Util
+{
 MESSAGELIST_EXPORT void deleteConfig(const QString &collectionId);
 MESSAGELIST_EXPORT QColor unreadDefaultMessageColor();
 MESSAGELIST_EXPORT QColor importantDefaultMessageColor();
@@ -25,5 +27,3 @@ MESSAGELIST_EXPORT QColor todoDefaultMessageColor();
 MESSAGELIST_EXPORT QString contentSummary(const Akonadi::Item &item);
 }
 }
-
-#endif /* MESSAGELISTUTIL_H */
