@@ -434,8 +434,8 @@ Q_SIGNALS:
     void forceLostFocus();
 
 private:
-    void restoreHeaderSettings(int index, bool restoreSession);
-    void readConfig(bool restoreSession);
+    MESSAGELIST_NO_EXPORT void restoreHeaderSettings(int index, bool restoreSession);
+    MESSAGELIST_NO_EXPORT void readConfig(bool restoreSession);
 
     bool eventFilter(QObject *obj, QEvent *event) override;
 
