@@ -36,7 +36,7 @@ AggregationEditor::AggregationEditor(QWidget *parent)
     mGroupingCombo = new QComboBox(tab);
     tabg->addWidget(mGroupingCombo, 0, 1);
 
-    connect(mGroupingCombo, qOverload<int>(&QComboBox::activated), this, &AggregationEditor::groupingComboActivated);
+    connect(mGroupingCombo, &QComboBox::activated, this, &AggregationEditor::groupingComboActivated);
 
     tabg->addWidget(new QLabel(i18n("Group expand policy:"), tab), 3, 0);
     mGroupExpandPolicyCombo = new QComboBox(tab);
@@ -46,7 +46,7 @@ AggregationEditor::AggregationEditor(QWidget *parent)
     mThreadingCombo = new QComboBox(tab);
     tabg->addWidget(mThreadingCombo, 4, 1);
 
-    connect(mThreadingCombo, qOverload<int>(&QComboBox::activated), this, &AggregationEditor::threadingComboActivated);
+    connect(mThreadingCombo, &QComboBox::activated, this, &AggregationEditor::threadingComboActivated);
 
     tabg->addWidget(new QLabel(i18n("Thread leader:"), tab), 5, 0);
     mThreadLeaderCombo = new QComboBox(tab);
@@ -80,9 +80,7 @@ AggregationEditor::AggregationEditor(QWidget *parent)
     fillGroupExpandPolicyCombo();
 }
 
-AggregationEditor::~AggregationEditor()
-{
-}
+AggregationEditor::~AggregationEditor() = default;
 
 void AggregationEditor::editAggregation(Aggregation *set)
 {
