@@ -18,7 +18,6 @@
 #include <QGridLayout>
 #include <QMap>
 #include <QPushButton>
-#include <kwidgetsaddons_version.h>
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -108,6 +107,9 @@ ConfigureThemesDialog::ConfigureThemesDialog(QWidget *parent)
     d->mThemeList->setSortingEnabled(true);
     g->addWidget(d->mThemeList, 0, 0, 7, 1);
 
+    connect(d->mThemeList, &ThemeListWidget::currentItemChanged, this, [this](QListWidgetItem *item) {
+        d->themeListItemClicked(item);
+    });
     connect(d->mThemeList, &ThemeListWidget::itemClicked, this, [this](QListWidgetItem *item) {
         d->themeListItemClicked(item);
     });
@@ -206,7 +208,7 @@ void ConfigureThemesDialog::ConfigureThemesDialogPrivate::okButtonClicked()
 
     Manager::instance()->themesConfigurationCompleted();
     Q_EMIT q->okClicked();
-    q->close(); // this will delete too
+    q->accept(); // this will delete too
 }
 
 void ConfigureThemesDialog::ConfigureThemesDialogPrivate::commitEditor()
@@ -357,6 +359,7 @@ void ConfigureThemesDialog::ConfigureThemesDialogPrivate::newThemeButtonClicked(
     emptyTheme.addColumn(col);
     auto item = new ThemeListWidgetItem(mThemeList, emptyTheme);
 
+    mThemeList->clearSelection();
     mThemeList->setCurrentItem(item);
     Core::Theme *theme = item->theme();
     if (theme) {
@@ -403,17 +406,9 @@ void ConfigureThemesDialog::ConfigureThemesDialogPrivate::deleteThemeButtonClick
         return;
     }
     const QString question = list.count() > 1 ? i18n("Do you want to delete selected themes?") : i18n("Do you want to delete \"%1\"?", list.first()->text());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     const int answer =
         KMessageBox::questionTwoActions(q, question, i18nc("@title:window", "Delete Theme"), KStandardGuiItem::del(), KStandardGuiItem::cancel());
-#else
-    const int answer = KMessageBox::questionYesNo(q, question, i18nc("@title:window", "Delete Theme"), KStandardGuiItem::del(), KStandardGuiItem::cancel());
-#endif
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (answer == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-    if (answer == KMessageBox::Yes) {
-#endif
         mEditor->editTheme(nullptr); // forget it
         for (QListWidgetItem *it : list) {
             auto item = dynamic_cast<ThemeListWidgetItem *>(it);
