@@ -479,8 +479,11 @@ void ThemePreviewWidget::internalHandleDragMoveEvent(QDragMoveEvent *e)
     }
 
     Theme::ContentItem::Type type = *((Theme::ContentItem::Type *)arry.data());
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (!computeContentItemInsertPosition(e->pos(), type)) {
+#else
+    if (!computeContentItemInsertPosition(e->position().toPoint(), type)) {
+#endif
         return;
     }
 
@@ -525,8 +528,11 @@ void ThemePreviewWidget::dropEvent(QDropEvent *e)
     }
 
     Theme::ContentItem::Type type = *((Theme::ContentItem::Type *)arry.data());
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (!computeContentItemInsertPosition(e->pos(), type)) {
+#else
+    if (!computeContentItemInsertPosition(e->position().toPoint(), type)) {
+#endif
         viewport()->update();
         return;
     }
@@ -1450,7 +1456,7 @@ ThemeEditor::ThemeEditor(QWidget *parent)
     mIconSizeSpinBox->setMaximum(64);
     mIconSizeSpinBox->setSuffix(ki18ncp("suffix in a spinbox", " pixel", " pixels"));
 
-    QObject::connect(mIconSizeSpinBox, qOverload<int>(&KPluralHandlingSpinBox::valueChanged), this, &ThemeEditor::slotIconSizeSpinBoxValueChanged);
+    QObject::connect(mIconSizeSpinBox, &KPluralHandlingSpinBox::valueChanged, this, &ThemeEditor::slotIconSizeSpinBoxValueChanged);
 
     tabg->addWidget(mIconSizeSpinBox, 1, 1);
 
