@@ -50,9 +50,9 @@ public:
     {
     }
 
-    Akonadi::Item::List selectionAsItems() const;
-    Akonadi::Item itemForRow(int row) const;
-    KMime::Message::Ptr messageForRow(int row) const;
+    Q_REQUIRED_RESULT Akonadi::Item::List selectionAsItems() const;
+    Q_REQUIRED_RESULT Akonadi::Item itemForRow(int row) const;
+    Q_REQUIRED_RESULT KMime::Message::Ptr messageForRow(int row) const;
 
     Widget *const q;
 
@@ -357,6 +357,12 @@ void MessageList::Widget::viewGroupHeaderContextPopupRequest(MessageList::Core::
     act = menu.addAction(i18n("Collapse All Groups"));
     connect(act, &QAction::triggered, view(), &Core::View::slotCollapseAllGroups);
 
+    menu.addSeparator();
+    act = menu.addAction(i18n("Expand All Threads"));
+    connect(act, &QAction::triggered, view(), &Core::View::slotExpandAllThreads);
+    act = menu.addAction(i18n("Collapse All Threads"));
+    connect(act, &QAction::triggered, view(), &Core::View::slotCollapseAllThreads);
+
     menu.exec(globalPos);
 }
 
@@ -536,7 +542,7 @@ Akonadi::Item MessageList::Widget::currentItem() const
     Core::MessageItem *mi = view()->currentMessageItem();
 
     if (mi == nullptr) {
-        return Akonadi::Item();
+        return {};
     }
 
     return d->itemForRow(mi->currentModelIndexRow());
@@ -547,7 +553,7 @@ KMime::Message::Ptr MessageList::Widget::currentMessage() const
     Core::MessageItem *mi = view()->currentMessageItem();
 
     if (mi == nullptr) {
-        return KMime::Message::Ptr();
+        return {};
     }
 
     return d->messageForRow(mi->currentModelIndexRow());
@@ -731,7 +737,7 @@ Akonadi::Collection MessageList::Widget::currentCollection() const
 {
     Collection::List collections = static_cast<const MessageList::StorageModel *>(storageModel())->displayedCollections();
     if (collections.size() != 1) {
-        return Akonadi::Collection(); // no folder here or too many (in case we can't decide where the drop will end)
+        return {}; // no folder here or too many (in case we can't decide where the drop will end)
     }
     return collections.first();
 }
