@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,8 +7,8 @@
 #include "mailsourceviewtextbrowserwidgettest.h"
 #include "../src/findbar/findbarsourceview.h"
 #include "../src/widgets/mailsourceviewtextbrowserwidget.h"
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
-#include <KPIMTextEdit/TextToSpeechWidget>
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#include <TextEditTextToSpeech/TextToSpeechContainerWidget>
 #endif
 #include <QTest>
 
@@ -30,10 +30,10 @@ void MailSourceViewTextBrowserWidgetTest::shouldHaveDefaultValue()
     QVERIFY(findbar);
     QVERIFY(findbar->isHidden());
 
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
-    auto texttospeechwidget = widget.findChild<KPIMTextEdit::TextToSpeechWidget *>(QStringLiteral("texttospeech"));
-    QVERIFY(texttospeechwidget);
-    QVERIFY(texttospeechwidget->isHidden());
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    auto TextToSpeechContainerWidget = widget.findChild<TextEditTextToSpeech::TextToSpeechContainerWidget *>(QStringLiteral("texttospeech"));
+    QVERIFY(TextToSpeechContainerWidget);
+    QVERIFY(TextToSpeechContainerWidget->isHidden());
 #endif
 }
 
