@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -23,15 +23,15 @@ DKIMManageRulesWidgetTest::DKIMManageRulesWidgetTest(QObject *parent)
 void DKIMManageRulesWidgetTest::shouldHaveDefaultValues()
 {
     MessageViewer::DKIMManageRulesWidget w;
-    auto *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
 
-    auto *mTreeWidget = w.findChild<QTreeWidget *>(QStringLiteral("treewidget"));
+    auto mTreeWidget = w.findChild<QTreeWidget *>(QStringLiteral("treewidget"));
     QVERIFY(mTreeWidget);
     QVERIFY(!mTreeWidget->rootIsDecorated());
     QVERIFY(mTreeWidget->alternatingRowColors());
 
-    auto *searchLineEdit = w.findChild<KTreeWidgetSearchLine *>(QStringLiteral("searchlineedit"));
+    auto searchLineEdit = w.findChild<KTreeWidgetSearchLine *>(QStringLiteral("searchlineedit"));
     QVERIFY(searchLineEdit->isClearButtonEnabled());
 }
