@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,9 +11,7 @@
 #include <QRegularExpressionMatch>
 using namespace MessageViewer;
 // see https://tools.ietf.org/html/rfc7601
-DKIMAuthenticationStatusInfo::DKIMAuthenticationStatusInfo()
-{
-}
+DKIMAuthenticationStatusInfo::DKIMAuthenticationStatusInfo() = default;
 
 bool DKIMAuthenticationStatusInfo::parseAuthenticationStatus(const QString &key, bool relaxingParsing)
 {
