@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -38,8 +38,8 @@ Q_SIGNALS:
     void result(const MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult &checkResult);
 
 private:
-    void compareWithDefaultRules();
-    void dmarcPolicyResult(const MessageViewer::DMARCPolicyJob::DMARCResult &value, const QString &emailAddress);
+    MESSAGEVIEWER_NO_EXPORT void compareWithDefaultRules();
+    MESSAGEVIEWER_NO_EXPORT void dmarcPolicyResult(const MessageViewer::DMARCPolicyJob::DMARCResult &value, const QString &emailAddress);
     MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult mCheckResult;
     QString mEmailAddress;
     DKIMCheckPolicy mPolicy;
