@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -41,7 +41,7 @@ Q_SIGNALS:
     void success(const QList<QByteArray> &, const QString &domain, const QString &selector);
 
 private:
-    void resolvDnsDone();
+    MESSAGEVIEWER_NO_EXPORT void resolvDnsDone();
     QString mDomainName;
     QString mSelectorName;
     QDnsLookup *mDnsLookup = nullptr;
