@@ -1,22 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMGENERATERULEJOB_H
-#define DKIMGENERATERULEJOB_H
+#pragma once
 
-#include <QObject>
 #include "dkimchecksignaturejob.h"
 #include "messageviewer_private_export.h"
-namespace MessageViewer {
+#include <QObject>
+namespace MessageViewer
+{
 class MESSAGEVIEWER_TESTS_EXPORT DKIMGenerateRuleJob : public QObject
 {
     Q_OBJECT
 public:
     explicit DKIMGenerateRuleJob(QObject *parent = nullptr);
-    ~DKIMGenerateRuleJob();
+    ~DKIMGenerateRuleJob() override;
 
     Q_REQUIRED_RESULT bool canStart() const;
     Q_REQUIRED_RESULT bool start();
@@ -29,4 +29,3 @@ private:
     DKIMCheckSignatureJob::CheckSignatureResult mResult;
 };
 }
-#endif // DKIMGENERATERULEJOB_H
