@@ -1,12 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dkimmanagerkey.h"
 #include "dkimutil.h"
-#include <KSharedConfig>
 #include <KConfig>
 #include <KConfigGroup>
 #include <QRegularExpression>
@@ -14,8 +13,8 @@
 using namespace MessageViewer;
 DKIMManagerKey::DKIMManagerKey(QObject *parent)
     : QObject(parent)
+    , mQcaInitializer(new QCA::Initializer(QCA::Practical, 64))
 {
-    mQcaInitializer = new QCA::Initializer(QCA::Practical, 64);
     loadKeys();
 }
 
@@ -33,7 +32,7 @@ DKIMManagerKey *DKIMManagerKey::self()
 
 QString DKIMManagerKey::keyValue(const QString &selector, const QString &domain)
 {
-    for (const KeyInfo &keyInfo : qAsConst(mKeys)) {
+    for (const KeyInfo &keyInfo : std::as_const(mKeys)) {
         if (keyInfo.selector == selector && keyInfo.domain == domain) {
             return keyInfo.keyValue;
         }
@@ -41,6 +40,18 @@ QString DKIMManagerKey::keyValue(const QString &selector, const QString &domain)
     return {};
 }
 
+void DKIMManagerKey::updateLastUsed(const QString &selector, const QString &domain)
+{
+    for (const KeyInfo &keyInfo : std::as_const(mKeys)) {
+        if (keyInfo.selector == selector && keyInfo.domain == domain) {
+            KeyInfo newKey = keyInfo;
+            newKey.lastUsedDateTime = QDateTime::currentDateTime();
+            addKey(newKey);
+            return;
+        }
+    }
+}
+
 void DKIMManagerKey::addKey(const KeyInfo &key)
 {
     const QVector<KeyInfo> keys = mKeys;
@@ -54,7 +65,7 @@ void DKIMManagerKey::addKey(const KeyInfo &key)
 
 void DKIMManagerKey::removeKey(const QString &key)
 {
-    for (const KeyInfo &keyInfo : qAsConst(mKeys)) {
+    for (const KeyInfo &keyInfo : std::as_const(mKeys)) {
         if (keyInfo.keyValue == key) {
             mKeys.removeAll(keyInfo);
             break;
@@ -70,8 +81,7 @@ QVector<KeyInfo> DKIMManagerKey::keys() const
 QStringList DKIMManagerKey::keyRecorderList(KSharedConfig::Ptr &config) const
 {
     config = KSharedConfig::openConfig(MessageViewer::DKIMUtil::defaultConfigFileName(), KConfig::NoGlobals);
-    const QStringList keyGroups
-        = config->groupList().filter(QRegularExpression(QStringLiteral("DKIM Key Record #\\d+")));
+    const QStringList keyGroups = config->groupList().filter(QRegularExpression(QStringLiteral("DKIM Key Record #\\d+")));
     return keyGroups;
 }
 
@@ -86,7 +96,12 @@ void DKIMManagerKey::loadKeys()
         const QString selector = group.readEntry(QStringLiteral("Selector"), QString());
         const QString domain = group.readEntry(QStringLiteral("Domain"), QString());
         const QString key = group.readEntry(QStringLiteral("Key"), QString());
-        mKeys.append(KeyInfo{key, selector, domain});
+        const QDateTime storedAt = QDateTime::fromString(group.readEntry(QStringLiteral("StoredAt"), QString()), Qt::ISODate);
+        QDateTime lastUsed = QDateTime::fromString(group.readEntry(QStringLiteral("LastUsed"), QString()), Qt::ISODate);
+        if (!lastUsed.isValid()) {
+            lastUsed = storedAt;
+        }
+        mKeys.append(KeyInfo{key, selector, domain, storedAt, lastUsed});
     }
 }
 
@@ -105,6 +120,8 @@ void DKIMManagerKey::saveKeys()
         group.writeEntry(QStringLiteral("Selector"), info.selector);
         group.writeEntry(QStringLiteral("Domain"), info.domain);
         group.writeEntry(QStringLiteral("Key"), info.keyValue);
+        group.writeEntry(QStringLiteral("StoredAt"), info.storedAtDateTime.toString(Qt::ISODate));
+        group.writeEntry(QStringLiteral("LastUsed"), info.lastUsedDateTime.toString(Qt::ISODate));
     }
 }
 
@@ -114,22 +131,22 @@ void DKIMManagerKey::saveKeys(const QVector<MessageViewer::KeyInfo> &lst)
     saveKeys();
 }
 
-bool KeyInfo::operator ==(const KeyInfo &other) const
+bool KeyInfo::operator==(const KeyInfo &other) const
 {
-    return keyValue == other.keyValue
-           && selector == other.selector
-            && domain == other.domain;
+    return keyValue == other.keyValue && selector == other.selector && domain == other.domain;
 }
 
-bool KeyInfo::operator !=(const KeyInfo &other) const
+bool KeyInfo::operator!=(const KeyInfo &other) const
 {
-    return !(operator ==(other));
+    return !(operator==(other));
 }
 
-QDebug operator <<(QDebug d, const KeyInfo &t)
+QDebug operator<<(QDebug d, const KeyInfo &t)
 {
     d << " keyvalue " << t.keyValue;
     d << " selector " << t.selector;
     d << " domain " << t.domain;
+    d << " storedAtDateTime " << t.storedAtDateTime;
+    d << " lastUsedDateTime " << t.lastUsedDateTime;
     return d;
 }
