@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,40 +8,47 @@
 #include "dkimmanager.h"
 #include "dkimutil.h"
 #include "messageviewer_dkimcheckerdebug.h"
-#include <KLocalizedString>
 #include <KColorScheme>
+#include <KLocalizedString>
 
-#include <QLabel>
 #include <QHBoxLayout>
+#include <QLabel>
 
 using namespace MessageViewer;
 DKIMWidgetInfo::DKIMWidgetInfo(QWidget *parent)
     : QWidget(parent)
+    , mLabel(new QLabel(this))
 {
-    QHBoxLayout *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setContentsMargins({});
 
-    mLabel = new QLabel(this);
     mLabel->setAutoFillBackground(true);
     mLabel->setObjectName(QStringLiteral("label"));
     mainLayout->addWidget(mLabel);
     connect(DKIMManager::self(), &DKIMManager::result, this, &DKIMWidgetInfo::setResult);
     connect(DKIMManager::self(), &DKIMManager::clearInfo, this, &DKIMWidgetInfo::clear);
     initColors();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    connect(qApp, &QApplication::paletteChanged, this, &DKIMWidgetInfo::updatePalette);
+#endif
 }
 
-DKIMWidgetInfo::~DKIMWidgetInfo()
+DKIMWidgetInfo::~DKIMWidgetInfo() = default;
+
+void DKIMWidgetInfo::updatePalette()
 {
+    initColors();
+    updateInfo();
 }
 
 void DKIMWidgetInfo::initColors()
 {
-    const KColorScheme colorScheme {QPalette::Active};
+    const KColorScheme colorScheme{QPalette::Active};
     mWarningColor = colorScheme.background(KColorScheme::NeutralBackground).color();
     mErrorColor = colorScheme.background(KColorScheme::NegativeBackground).color();
     mOkColor = colorScheme.background(KColorScheme::PositiveBackground).color();
-    mDefaultColor = palette().window().color();
+    mDefaultColor = colorScheme.background(KColorScheme::ActiveBackground).color();
 }
 
 MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult DKIMWidgetInfo::result() const
@@ -90,6 +97,9 @@ void DKIMWidgetInfo::updateInfo()
         mLabel->setText(i18n("Unknown"));
         break;
     case DKIMCheckSignatureJob::DKIMStatus::Valid:
+        if (mResult.sdid.isEmpty()) {
+            qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << "mResult.sdid is empty. It's a bug";
+        }
         mLabel->setText(i18n("DKIM: valid (signed by %1)", mResult.sdid));
         pal.setColor(backgroundRole(), (mResult.warning != DKIMCheckSignatureJob::DKIMWarning::Any) ? mWarningColor : mOkColor);
         mLabel->setPalette(pal);
@@ -190,7 +200,7 @@ void DKIMWidgetInfo::updateToolTip()
         tooltip += (tooltip.isEmpty() ? QChar() : QLatin1Char('\n')) + i18n("Signature expired");
         break;
     case DKIMCheckSignatureJob::DKIMWarning::SignatureCreatedInFuture:
-        tooltip += (tooltip.isEmpty() ? QChar() : QLatin1Char('\n'))  + i18n("Signature created in the future");
+        tooltip += (tooltip.isEmpty() ? QChar() : QLatin1Char('\n')) + i18n("Signature created in the future");
         break;
     case DKIMCheckSignatureJob::DKIMWarning::SignatureTooSmall:
         tooltip += (tooltip.isEmpty() ? QChar() : QLatin1Char('\n')) + i18n("Signature too small");
@@ -205,12 +215,12 @@ void DKIMWidgetInfo::updateToolTip()
 
     if (mResult.status != DKIMCheckSignatureJob::DKIMStatus::Invalid) {
         QStringList tooltipList;
-        for (const DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult &result : qAsConst(mResult.listSignatureAuthenticationResult)) {
+        for (const DKIMCheckSignatureJob::DKIMCheckSignatureAuthenticationResult &result : std::as_const(mResult.listSignatureAuthenticationResult)) {
             switch (result.status) {
             case DKIMCheckSignatureJob::DKIMStatus::Unknown:
                 break;
             case DKIMCheckSignatureJob::DKIMStatus::Invalid:
-                switch(result.method) {
+                switch (result.method) {
                 case DKIMCheckSignatureJob::AuthenticationMethod::Unknown: {
                     break;
                 }
@@ -219,7 +229,10 @@ void DKIMWidgetInfo::updateToolTip()
                 case DKIMCheckSignatureJob::AuthenticationMethod::Dmarc:
                 case DKIMCheckSignatureJob::AuthenticationMethod::Auth:
                 case DKIMCheckSignatureJob::AuthenticationMethod::Dkimatps: {
-                    const QString str = i18nc("method name: info about it from parsing", "%1: %2", MessageViewer::DKIMUtil::convertAuthenticationMethodEnumToString(result.method), result.infoResult);
+                    const QString str = i18nc("method name: info about it from parsing",
+                                              "%1: %2",
+                                              MessageViewer::DKIMUtil::convertAuthenticationMethodEnumToString(result.method),
+                                              result.infoResult);
                     if (!tooltipList.contains(str)) {
                         tooltipList.append(str);
                     }
@@ -231,7 +244,7 @@ void DKIMWidgetInfo::updateToolTip()
             case DKIMCheckSignatureJob::DKIMStatus::NeedToBeSigned:
                 break;
             case DKIMCheckSignatureJob::DKIMStatus::EmailNotSigned:
-                switch(result.method) {
+                switch (result.method) {
                 case DKIMCheckSignatureJob::AuthenticationMethod::Unknown: {
                     break;
                 }
@@ -249,20 +262,23 @@ void DKIMWidgetInfo::updateToolTip()
                 }
                 break;
             case DKIMCheckSignatureJob::DKIMStatus::Valid:
-                switch(result.method) {
+                switch (result.method) {
                 case DKIMCheckSignatureJob::AuthenticationMethod::Unknown: {
                     break;
                 }
                 case DKIMCheckSignatureJob::AuthenticationMethod::Dkim: {
-                    const QString str = i18n("%1: Valid (Signed by %2)", MessageViewer::DKIMUtil::convertAuthenticationMethodEnumToString(result.method),
-                                   result.sdid);
+                    const QString str =
+                        i18n("%1: Valid (Signed by %2)", MessageViewer::DKIMUtil::convertAuthenticationMethodEnumToString(result.method), result.sdid);
                     if (!tooltipList.contains(str)) {
                         tooltipList.append(str);
                     }
                     break;
                 }
                 case DKIMCheckSignatureJob::AuthenticationMethod::Spf: {
-                    const QString str = i18nc("method name: info about it from parsing", "%1: %2", MessageViewer::DKIMUtil::convertAuthenticationMethodEnumToString(result.method), result.infoResult);
+                    const QString str = i18nc("method name: info about it from parsing",
+                                              "%1: %2",
+                                              MessageViewer::DKIMUtil::convertAuthenticationMethodEnumToString(result.method),
+                                              result.infoResult);
                     if (!tooltipList.contains(str)) {
                         tooltipList.append(str);
                     }
@@ -287,11 +303,20 @@ void DKIMWidgetInfo::updateToolTip()
             tooltip += (tooltip.isEmpty() ? QChar() : QLatin1Char('\n')) + tooltipList.join(QLatin1Char('\n'));
         }
         if (mResult.listSignatureAuthenticationResult.isEmpty()) {
-            tooltip += (tooltip.isEmpty() ? QChar() : QLatin1Char('\n'))
-                    + i18n("Not Signed");
+            tooltip += (tooltip.isEmpty() ? QChar() : QLatin1Char('\n')) + i18n("Not Signed");
         }
     }
     qCDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "mResult.authentication " << mResult.listSignatureAuthenticationResult;
 
     mLabel->setToolTip(tooltip);
 }
+
+bool DKIMWidgetInfo::event(QEvent *e)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    if (e->type() == QEvent::ApplicationPaletteChange) {
+        updatePalette();
+    }
+#endif
+    return QWidget::event(e);
+}
