@@ -4,7 +4,7 @@
     This file is part of KMail, the KDE mail client.
     SPDX-FileCopyrightText: 2003 Marc Mutz <mutz@kde.org>
 
-    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,22 +15,18 @@
 // HeaderStrategy abstract base:
 //
 using namespace MessageViewer;
-HeaderStrategy::HeaderStrategy()
-{
-}
+HeaderStrategy::HeaderStrategy() = default;
 
-HeaderStrategy::~HeaderStrategy()
-{
-}
+HeaderStrategy::~HeaderStrategy() = default;
 
 QStringList HeaderStrategy::headersToDisplay() const
 {
-    return QStringList();
+    return {};
 }
 
 QStringList HeaderStrategy::headersToHide() const
 {
-    return QStringList();
+    return {};
 }
 
 bool HeaderStrategy::showHeader(const QString &header) const
