@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ ModifyMessageDisplayFormatJob::ModifyMessageDisplayFormatJob(Akonadi::Session *s
 {
 }
 
-ModifyMessageDisplayFormatJob::~ModifyMessageDisplayFormatJob()
-{
-}
+ModifyMessageDisplayFormatJob::~ModifyMessageDisplayFormatJob() = default;
 
 void ModifyMessageDisplayFormatJob::setRemoteContent(bool remote)
 {
