@@ -66,9 +66,9 @@ TestCSSHelper::TestCSSHelper(const QPaintDevice *pd)
 
 TestCSSHelper::~TestCSSHelper() = default;
 
-QString TestCSSHelper::htmlHead(bool fixed) const
+QString TestCSSHelper::htmlHead(const HtmlHeadSettings &htmlHeadSettings) const
 {
-    Q_UNUSED(fixed)
+    Q_UNUSED(htmlHeadSettings)
     return QStringLiteral(
         "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n"
         "<html>\n"
