@@ -4,19 +4,20 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_HTMLBLOCK_H
-#define MIMETREEPARSER_HTMLBLOCK_H
+#pragma once
 
 #include "messageviewer_export.h"
 
-#include <QString>
 #include <QSharedPointer>
+#include <QString>
 
-namespace KMime {
+namespace KMime
+{
 class Content;
 }
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class HtmlWriter;
 /**
  * @brief The HTMLBlock class
@@ -24,7 +25,7 @@ class HtmlWriter;
 class MESSAGEVIEWER_EXPORT HTMLBlock
 {
 public:
-    typedef QSharedPointer<HTMLBlock> Ptr;
+    using Ptr = QSharedPointer<HTMLBlock>;
 
     HTMLBlock();
 
@@ -32,6 +33,7 @@ public:
 
     Q_REQUIRED_RESULT Q_REQUIRED_RESULT QString enter();
     Q_REQUIRED_RESULT Q_REQUIRED_RESULT QString exit();
+
 protected:
     Q_REQUIRED_RESULT QString dir() const;
     virtual QString enterString() const = 0;
@@ -61,8 +63,8 @@ private:
     void internalEnter();
     void internalExit();
 
-    KMime::Content *mNode = nullptr;
-    HtmlWriter *mWriter = nullptr;
+    KMime::Content *const mNode;
+    HtmlWriter *const mWriter;
 };
 
 // Make sure the whole content is relative, so that nothing is painted over the header
@@ -85,4 +87,3 @@ private:
     HtmlWriter *mWriter = nullptr;
 };
 }
-#endif //__MIMETREEPARSER_HTMLBLOCK_H
