@@ -1,14 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "remotecontentinfo.h"
 using namespace MessageViewer;
-RemoteContentInfo::RemoteContentInfo()
-{
-}
+RemoteContentInfo::RemoteContentInfo() = default;
 
 RemoteContentInfo::~RemoteContentInfo() = default;
 
