@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -12,9 +12,7 @@ ScamAttributeTest::ScamAttributeTest(QObject *parent)
 {
 }
 
-ScamAttributeTest::~ScamAttributeTest()
-{
-}
+ScamAttributeTest::~ScamAttributeTest() = default;
 
 void ScamAttributeTest::shouldHaveDefaultValue()
 {
