@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -15,9 +15,7 @@ using namespace MessageViewer;
 class MessageViewer::ScamAttributePrivate
 {
 public:
-    ScamAttributePrivate()
-    {
-    }
+    ScamAttributePrivate() = default;
 
     bool isAScam = false;
 };
@@ -46,6 +44,7 @@ QByteArray ScamAttribute::serialized() const
 {
     QByteArray result;
     QDataStream s(&result, QIODevice::WriteOnly);
+    s.setVersion(QDataStream::Qt_5_15);
     s << isAScam();
     return result;
 }
@@ -53,6 +52,7 @@ QByteArray ScamAttribute::serialized() const
 void ScamAttribute::deserialize(const QByteArray &data)
 {
     QDataStream s(data);
+    s.setVersion(QDataStream::Qt_5_15);
     bool value = false;
     s >> value;
     d->isAScam = value;
