@@ -1,21 +1,19 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#include "scamcheckshorturl.h"
 #include "scamcheckshorturlmanager.h"
+#include "scamcheckshorturl.h"
 
 using namespace MessageViewer;
 
 class MessageViewer::ScamCheckShortUrlManagerPrivate
 {
 public:
-    ScamCheckShortUrlManagerPrivate()
-    {
-    }
+    ScamCheckShortUrlManagerPrivate() = default;
 
     ScamCheckShortUrl *mCheckShortUrl = nullptr;
 };
@@ -27,10 +25,7 @@ ScamCheckShortUrlManager::ScamCheckShortUrlManager(QObject *parent)
     d->mCheckShortUrl = new ScamCheckShortUrl(this);
 }
 
-ScamCheckShortUrlManager::~ScamCheckShortUrlManager()
-{
-    delete d;
-}
+ScamCheckShortUrlManager::~ScamCheckShortUrlManager() = default;
 
 ScamCheckShortUrlManager *ScamCheckShortUrlManager::self()
 {
