@@ -1,26 +1,27 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef SCAMDETECTIONDETAILSDIALOG_H
-#define SCAMDETECTIONDETAILSDIALOG_H
+#pragma once
 
 #include <QDialog>
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class RichTextEditorWidget;
 }
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class ScamDetectionDetailsDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit ScamDetectionDetailsDialog(QWidget *parent = nullptr);
-    ~ScamDetectionDetailsDialog();
+    ~ScamDetectionDetailsDialog() override;
 
     void setDetails(const QString &details);
 
@@ -28,8 +29,6 @@ private:
     void slotSaveAs();
     void writeConfig();
     void readConfig();
-    KPIMTextEdit::RichTextEditorWidget *mDetails = nullptr;
+    KPIMTextEdit::RichTextEditorWidget *const mDetails;
 };
 }
-
-#endif // SCAMDETECTIONDETAILSDIALOG_H
