@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -32,7 +32,7 @@ public Q_SLOTS:
     void showDetails();
 
 private Q_SLOTS:
-    void handleScanPage(const QVariant &result);
+    MESSAGEVIEWER_NO_EXPORT void handleScanPage(const QVariant &result);
 
 Q_SIGNALS:
     void messageMayBeAScam();
