@@ -1,39 +1,7 @@
-/*******************************************************************************
-**
-** Filename   : util
-** Created on : 03 April, 2005
-** SPDX-FileCopyrightText : 2005 Till Adam <adam@kde.org>
-**
-*******************************************************************************/
-
-/*******************************************************************************
-**
-**   This program is free software; you can redistribute it and/or modify
-**   it under the terms of the GNU General Public License as published by
-**   the Free Software Foundation; either version 2 of the License, or
-**   (at your option) any later version.
-**
-**   It is distributed in the hope that it will be useful, but
-**   WITHOUT ANY WARRANTY; without even the implied warranty of
-**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-**   General Public License for more details.
-**
-**   You should have received a copy of the GNU General Public License
-**   along with this program; if not, write to the Free Software
-**   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-**
-**   In addition, as a special exception, the copyright holders give
-**   permission to link the code of this program with any edition of
-**   the Qt library by Trolltech AS, Norway (or with modified versions
-**   of Qt that use the same license as Qt), and distribute linked
-**   combinations including the two.  You must obey the GNU General
-**   Public License in all respects for all of the code used other than
-**   Qt.  If you modify this file, you may extend this exception to
-**   your version of the file, but you are not obligated to do so.  If
-**   you do not wish to do so, delete this exception statement from
-**   your version.
-**
-*******************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2005 Till Adam <adam@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
+ */
 
 #include "messageviewer/messageviewerutil.h"
 #include "MessageCore/MessageCoreSettings"
@@ -50,7 +18,6 @@
 
 #include <KMbox/MBox>
 
-#include <KCharsets>
 #include <KFileWidget>
 #include <KIO/FileCopyJob>
 #include <KIO/StatJob>
@@ -68,7 +35,6 @@
 #include <QRegularExpression>
 #include <QTemporaryFile>
 #include <QWidget>
-#include <kwidgetsaddons_version.h>
 
 using namespace MessageViewer;
 /** Checks whether @p str contains external references. To be precise,
@@ -350,34 +316,20 @@ bool Util::saveContent(QWidget *parent, KMime::Content *content, const QUrl &url
     bool bEncryptedParts = mNodeHelper->encryptionState(content)
                            != MimeTreeParser::KMMsgNotEncrypted;
     if (bEncryptedParts) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (KMessageBox::questionTwoActions(parent,
-#else
-        if (KMessageBox::questionYesNo(parent,
-
-#endif
                                        i18n(
                                            "The part %1 of the message is encrypted. Do you want to keep the encryption when saving?",
                                            url.fileName()),
                                        i18n("KMail Question"), KGuiItem(i18n("Keep Encryption")),
                                        KGuiItem(i18n("Do Not Keep")))
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-            == KMessageBox::Yes) {
-#endif
             bSaveEncrypted = true;
         }
     }
 
     bool bSaveWithSig = true;
     if (mNodeHelper->signatureState(content) != MessageViewer::MimeTreeParser::KMMsgNotSigned) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (KMessageBox::questionTwoActions(parent,
-#else
-        if (KMessageBox::questionYesNo(parent,
-
-#endif
                                        i18n(
                                            "The part %1 of the message is signed. Do you want to keep the signature when saving?",
                                            url.fileName()),
@@ -665,7 +617,11 @@ const QTextCodec *Util::codecForName(const QByteArray &_str)
         return nullptr;
     }
     const QByteArray codec = _str.toLower();
-    return KCharsets::charsets()->codecForName(QLatin1String(codec));
+    auto codecFromName = QTextCodec::codecForName(codec);
+    if (!codecFromName) {
+        codecFromName = QTextCodec::codecForLocale();
+    }
+    return codecFromName;
 }
 
 void Util::readGravatarConfig()
@@ -687,11 +643,13 @@ QString Util::parseBodyStyle(const QString &style)
             const auto lstStyle = styleStr.split(QLatin1Char(';'), Qt::SkipEmptyParts);
             QStringList lst;
             for (const auto &style : lstStyle) {
-                if (!style.trimmed().contains(QLatin1String("white-space"))) {
+                // qDebug() << " style : " << style;
+                if (!style.trimmed().contains(QLatin1String("white-space")) && !style.trimmed().contains(QLatin1String("text-align"))) {
                     lst.append(style.toString().trimmed());
                 }
             }
             if (!lst.isEmpty()) {
+                // qDebug() << " lst " << lst;
                 return QStringLiteral(" style=\"%1").arg(lst.join(QLatin1Char(';'))) + QStringLiteral(";\"");
             }
         }
@@ -738,6 +696,17 @@ Util::HtmlMessageInfo Util::processHtml(const QString &htmlSource)
             messageInfo.extraHead.clear();
         }
         s = s.remove(startIndex, endIndex - startIndex + 7).trimmed();
+        // qDebug() << "BEFORE messageInfo.extraHead**********" << messageInfo.extraHead;
+        static QRegularExpression styleBodyRegularExpression =
+            QRegularExpression(QStringLiteral("<style>\\s*body\\s*{"), QRegularExpression::CaseInsensitiveOption | QRegularExpression::MultilineOption);
+        QRegularExpressionMatch matchBodyStyle;
+        const int bodyStyleStartIndex = messageInfo.extraHead.indexOf(styleBodyRegularExpression, 0, &matchBodyStyle);
+        if (bodyStyleStartIndex > 0) {
+            const auto endIndex = messageInfo.extraHead.indexOf(QLatin1String("</style>"), bodyStyleStartIndex, Qt::CaseInsensitive);
+            // qDebug() << " endIndex " << endIndex;
+            messageInfo.extraHead = messageInfo.extraHead.remove(bodyStyleStartIndex, endIndex - bodyStyleStartIndex + 8);
+        }
+        // qDebug() << "AFTER messageInfo.extraHead**********" << messageInfo.extraHead;
     }
     // body
     static QRegularExpression body = QRegularExpression(QStringLiteral("<body[^>]*>"), QRegularExpression::CaseInsensitiveOption);
