@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include "config-messageviewer.h"
+#include "csshelper.h"
 #include "messageviewer/viewerplugininterface.h"
 #include "messageviewer_private_export.h"
 #include "viewer.h" //not so nice, it is actually for the enums from MailViewer
@@ -24,7 +24,6 @@
 #include <QUrl>
 #include <QVector>
 #include <WebEngineViewer/CheckPhishingUrlUtil>
-#include <kpimtextedit/kpimtextedit-texttospeech.h>
 
 #include <QObject>
 #include <QTimer>
@@ -54,8 +53,13 @@ class IdentityManager;
 namespace KPIMTextEdit
 {
 class SlideContainer;
-class TextToSpeechWidget;
 }
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+namespace TextEditTextToSpeech
+{
+class TextToSpeechContainerWidget;
+}
+#endif
 
 namespace MimeTreeParser
 {
@@ -274,9 +278,6 @@ public:
     header style. */
     Q_REQUIRED_RESULT QString writeMessageHeader(KMime::Message *aMsg, KMime::Content *vCardNode, bool topLevel);
 
-    /** show window containing information about a vCard. */
-    void showVCard(KMime::Content *msgPart);
-
     void saveMainFrameScreenshotInFile(const QString &filename);
 
     void exportToPdf(const QString &fileName);
@@ -607,6 +608,7 @@ private:
 
     void slotCheckedUrlFinished(const QUrl &url, WebEngineViewer::CheckPhishingUrlUtil::UrlStatus status);
 
+    void adaptHtmlHeadSettings();
     void slotDelayPrintPreview();
     void applyZoomValue(qreal factor, bool saveConfig = true);
     void slotZoomChanged(qreal zoom);
@@ -640,7 +642,7 @@ public:
     /// the splash/busy page is displayed.
     bool mMsgDisplay = true;
 
-    bool mUseFixedFont = false;
+    CSSHelperBase::HtmlHeadSettings mHtmlHeadSettings;
     bool mPrinting = false;
     QWidget *mMainWindow = nullptr;
     KActionCollection *const mActionCollection;
@@ -700,8 +702,8 @@ public:
     MessageViewer::OpenSavedFileFolderWidget *mOpenSavedFileFolderWidget = nullptr;
     WebEngineViewer::SubmittedFormWarningWidget *mSubmittedFormWarning = nullptr;
     WebEngineViewer::TrackingWarningWidget *mMailTrackingWarning = nullptr;
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
-    KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    TextEditTextToSpeech::TextToSpeechContainerWidget *mTextToSpeechContainerWidget = nullptr;
 #endif
     Viewer::DisplayFormatMessage mDisplayFormatMessageOverwrite;
     KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
