@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,9 +11,7 @@ using namespace MessageViewer;
 class MessageViewer::ViewerPluginPrivate
 {
 public:
-    ViewerPluginPrivate()
-    {
-    }
+    ViewerPluginPrivate() = default;
 
     bool mEnabled = false;
 };
@@ -24,14 +22,11 @@ ViewerPlugin::ViewerPlugin(QObject *parent)
 {
 }
 
-ViewerPlugin::~ViewerPlugin()
-{
-    delete d;
-}
+ViewerPlugin::~ViewerPlugin() = default;
 
 void ViewerPlugin::showConfigureDialog(QWidget *parent)
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
 }
 
 bool ViewerPlugin::hasConfigureDialog() const
