@@ -13,8 +13,9 @@
 #include "messageviewer/messageviewerutil.h"
 #include "messageviewer_debug.h"
 #include <KPIMTextEdit/SlideContainer>
-#include <KPIMTextEdit/TextToSpeechInterface>
-#include <KPIMTextEdit/TextToSpeechWidget>
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#include <TextEditTextToSpeech/TextToSpeechContainerWidget>
+#endif
 #include <PimCommon/PimUtil>
 
 #include <KSyntaxHighlighting/Definition>
@@ -38,16 +39,19 @@ using namespace MessageViewer;
 MailSourceViewTextBrowserWidget::MailSourceViewTextBrowserWidget(const QString &syntax, QWidget *parent)
     : QWidget(parent)
     , mSliderContainer(new KPIMTextEdit::SlideContainer(this))
-    , mTextToSpeechWidget(new KPIMTextEdit::TextToSpeechWidget(this))
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    , mTextToSpeechContainerWidget(new TextEditTextToSpeech::TextToSpeechContainerWidget(this))
+#endif
 {
     auto lay = new QVBoxLayout(this);
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
     lay->setContentsMargins({});
-    mTextToSpeechWidget->setObjectName(QStringLiteral("texttospeech"));
-    lay->addWidget(mTextToSpeechWidget);
-
-    auto textToSpeechInterface = new KPIMTextEdit::TextToSpeechInterface(mTextToSpeechWidget, this);
-
-    mTextBrowser = new MailSourceViewTextBrowser(textToSpeechInterface);
+    mTextToSpeechContainerWidget->setObjectName(QStringLiteral("texttospeech"));
+    lay->addWidget(mTextToSpeechContainerWidget);
+    mTextBrowser = new MailSourceViewTextBrowser(mTextToSpeechContainerWidget);
+#else
+    mTextBrowser = new MailSourceViewTextBrowser(this);
+#endif
     mTextBrowser->setObjectName(QStringLiteral("textbrowser"));
     mTextBrowser->setLineWrapMode(QPlainTextEdit::NoWrap);
     mTextBrowser->setTextInteractionFlags(Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard);
@@ -104,10 +108,15 @@ MessageViewer::MailSourceViewTextBrowser *MailSourceViewTextBrowserWidget::textB
 {
     return mTextBrowser;
 }
-
-MailSourceViewTextBrowser::MailSourceViewTextBrowser(KPIMTextEdit::TextToSpeechInterface *textToSpeechInterface, QWidget *parent)
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+MailSourceViewTextBrowser::MailSourceViewTextBrowser(TextEditTextToSpeech::TextToSpeechContainerWidget *TextToSpeechContainerWidget, QWidget *parent)
+    : QPlainTextEdit(parent)
+    , mTextToSpeechContainerWidget(TextToSpeechContainerWidget)
+{
+}
+#endif
+MailSourceViewTextBrowser::MailSourceViewTextBrowser(QWidget *parent)
     : QPlainTextEdit(parent)
-    , mTextToSpeechInterface(textToSpeechInterface)
 {
 }
 
@@ -117,14 +126,13 @@ void MailSourceViewTextBrowser::contextMenuEvent(QContextMenuEvent *event)
     if (popup) {
         popup->addSeparator();
         popup->addAction(KStandardAction::find(this, &MailSourceViewTextBrowser::findText, this));
-        // Code from KTextBrowser
-        if (mTextToSpeechInterface->isReady()) {
-            popup->addSeparator();
-            popup->addAction(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")),
-                             i18n("Speak Text"),
-                             this,
-                             &MailSourceViewTextBrowser::slotSpeakText);
-        }
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+        popup->addSeparator();
+        popup->addAction(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")),
+                         i18n("Speak Text"),
+                         this,
+                         &MailSourceViewTextBrowser::slotSpeakText);
+#endif
         popup->addSeparator();
         popup->addAction(KStandardAction::saveAs(this, &MailSourceViewTextBrowser::slotSaveAs, this));
 
@@ -146,5 +154,7 @@ void MailSourceViewTextBrowser::slotSpeakText()
     } else {
         text = toPlainText();
     }
-    mTextToSpeechInterface->say(text);
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    mTextToSpeechContainerWidget->say(text);
+#endif
 }
