@@ -16,6 +16,7 @@
 
 #include <QProcess>
 #include <QTest>
+#include <QTextCodec>
 
 using namespace MimeTreeParser;
 
@@ -73,6 +74,23 @@ void ObjectTreeParserTest::testMailWithoutEncryption()
     QVERIFY(!nodeHelper.unencryptedMessage(originalMessage));
 }
 
+void ObjectTreeParserTest::testBinaryAttachmentNotPGP()
+{
+    KMime::Message::Ptr originalMessage = readAndParseMail(QStringLiteral("binary-attachment-not-pgp.mbox"));
+    NodeHelper nodeHelper;
+    SimpleObjectTreeSource testSource;
+    ObjectTreeParser otp(&testSource, &nodeHelper);
+    otp.parseObjectTree(originalMessage.data());
+
+    QCOMPARE(originalMessage->contentType()->mimeType().data(), "multipart/mixed");
+    QCOMPARE(originalMessage->contents().size(), 2);
+    QCOMPARE(originalMessage->contents().at(0)->contentType()->mimeType().data(), "text/plain");
+    QCOMPARE(originalMessage->contents().at(1)->contentType()->mimeType().data(), "application/msword");
+
+    QCOMPARE(nodeHelper.encryptionState(originalMessage->contents().at(0)), KMMsgNotEncrypted);
+    QCOMPARE(nodeHelper.encryptionState(originalMessage->contents().at(1)), KMMsgNotEncrypted);
+}
+
 void ObjectTreeParserTest::testSignedForwardedOpenPGPSignedEncrypted()
 {
     KMime::Message::Ptr originalMessage = readAndParseMail(QStringLiteral("signed-forward-openpgp-signed-encrypted.mbox"));
@@ -235,6 +253,27 @@ void ObjectTreeParserTest::testOpenPGPEncryptedNotDecrypted()
     QVERIFY(!unencryptedMessage);
 }
 
+void ObjectTreeParserTest::testOpenPGPEncryptedOverrideEncoding()
+{
+    KMime::Message::Ptr originalMessage = readAndParseMail(QStringLiteral("openpgp-encrypted-attachment-iso-8859-15-encoded.mbox"));
+
+    NodeHelper nodeHelper;
+    SimpleObjectTreeSource testSource;
+    testSource.setDecryptMessage(true);
+    const QString data = QStringLiteral(
+        "german umlauts ISO-8859-15:\n\u00c3\u20ac - a with two dots - utf-8: U+00C3 U20AC\n\u00c3\u009f - eszett or \"sharp s\" - utf-8: U+00C3 U+009F\n");
+    ObjectTreeParser otp(&testSource, &nodeHelper);
+    otp.parseObjectTree(originalMessage.data());
+
+    QCOMPARE(nodeHelper.overallEncryptionState(originalMessage.data()), KMMsgFullyEncrypted);
+
+    QVERIFY(otp.plainTextContent() != data); // it is not utf-8
+
+    testSource.setOverrideCodec(QTextCodec::codecForName("iso-8859-15"));
+    otp.parseObjectTree(originalMessage.data());
+    QCOMPARE(otp.plainTextContent(), data);
+}
+
 void ObjectTreeParserTest::testAsync_data()
 {
     QTest::addColumn<QString>("mailFileName");
