@@ -16,7 +16,7 @@ class MailmanBodyPartFormatter : public Interface::BodyPartFormatter
     static const MailmanBodyPartFormatter *self;
 
 public:
-    MessagePartPtr process(Interface::BodyPart &part) const override;
+    Q_REQUIRED_RESULT MessagePartPtr process(Interface::BodyPart &part) const override;
     static const Interface::BodyPartFormatter *create();
 
 private:
