@@ -16,8 +16,7 @@ class MultiPartAlternativeBodyPartFormatter : public Interface::BodyPartFormatte
     static const MultiPartAlternativeBodyPartFormatter *self;
 
 public:
-    MessagePartPtr process(Interface::BodyPart &part) const override;
+    Q_REQUIRED_RESULT MessagePartPtr process(Interface::BodyPart &part) const override;
     static const Interface::BodyPartFormatter *create();
 };
 }
-
