@@ -16,7 +16,7 @@ class TextPlainBodyPartFormatter : public Interface::BodyPartFormatter
     static const TextPlainBodyPartFormatter *self;
 
 public:
-    MessagePartPtr process(Interface::BodyPart &part) const override;
+    Q_REQUIRED_RESULT MessagePartPtr process(Interface::BodyPart &part) const override;
     static const Interface::BodyPartFormatter *create();
 };
 }
