@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,13 +12,10 @@ using namespace MimeTreeParser;
 CryptoBodyPartMemento::CryptoBodyPartMemento()
     : QObject(nullptr)
     , Interface::BodyPartMemento()
-    , m_running(false)
 {
 }
 
-CryptoBodyPartMemento::~CryptoBodyPartMemento()
-{
-}
+CryptoBodyPartMemento::~CryptoBodyPartMemento() = default;
 
 bool CryptoBodyPartMemento::isRunning() const
 {
