@@ -10,8 +10,6 @@
 
 #pragma once
 
-#include "mimetreeparser_export.h"
-
 #include <gpgme++/context.h>
 #include <gpgme++/verificationresult.h>
 
@@ -24,29 +22,30 @@ class PartMetaData
 {
 public:
     PartMetaData()
-        : sigSummary(GpgME::Signature::None)
-        , isSigned(false)
+        : isSigned(false)
         , isGoodSignature(false)
         , isEncrypted(false)
         , isDecryptable(false)
         , inProgress(false)
         , technicalProblem(false)
         , isEncapsulatedRfc822Message(false)
+        , isCompliant(false)
     {
     }
 
-    GpgME::Signature::Summary sigSummary;
+    GpgME::Signature::Summary sigSummary = GpgME::Signature::None;
     QString signClass;
     QString signer;
     QStringList signerMailAddresses;
     QByteArray keyId;
-    GpgME::Signature::Validity keyTrust;
+    GpgME::Signature::Validity keyTrust = GpgME::Signature::Validity::Unknown;
     QString status; // to be used for unknown plug-ins
-    int status_code; // to be used for i18n of OpenPGP and S/MIME CryptPlugs
+    int status_code = 0; // = GPGME_SIG_STAT_NONE; to be used for i18n of OpenPGP and S/MIME CryptPlugs
     QString errorText;
     QDateTime creationTime;
     QString decryptionError;
     QString auditLog;
+    QString compliance; // textual representation of compliance status; empty if compliance isn't enforced
     GpgME::Error auditLogError;
     bool isSigned : 1;
     bool isGoodSignature : 1;
@@ -55,5 +54,6 @@ public:
     bool inProgress : 1;
     bool technicalProblem : 1;
     bool isEncapsulatedRfc822Message : 1;
+    bool isCompliant : 1; // corresponds to the isDeVS flag of signature or decryption result
 };
 }
