@@ -1,6 +1,6 @@
 /*
  * SPDX-FileCopyrightText: 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
- * SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -58,7 +58,7 @@ CustomTemplates::CustomTemplates(const QList<KActionCollection *> &actionCollect
     connect(mUi->mDuplicate, &QPushButton::clicked, this, &CustomTemplates::slotDuplicateClicked);
     connect(mUi->mList, &QTreeWidget::currentItemChanged, this, &CustomTemplates::slotListSelectionChanged);
     connect(mUi->mList, &QTreeWidget::itemChanged, this, &CustomTemplates::slotItemChanged);
-    connect(mUi->mType, qOverload<int>(&QComboBox::activated), this, &CustomTemplates::slotTypeActivated);
+    connect(mUi->mType, &QComboBox::activated, this, &CustomTemplates::slotTypeActivated);
 
     connect(mUi->mKeySequenceWidget, &KKeySequenceWidget::keySequenceChanged, this, &CustomTemplates::slotShortcutChanged);
 
