@@ -40,14 +40,11 @@ Q_SIGNALS:
     void replyAllTemplateSelected(const QString &tmpl);
     void forwardTemplateSelected(const QString &tmpl);
 
-private Q_SLOTS:
-    void slotReplySelected(int idx);
-    void slotReplyAllSelected(int idx);
-    void slotForwardSelected(int idx);
-
 private:
-    void clear();
+    TEMPLATEPARSER_NO_EXPORT void slotReplySelected(int idx);
+    TEMPLATEPARSER_NO_EXPORT void slotReplyAllSelected(int idx);
+    TEMPLATEPARSER_NO_EXPORT void slotForwardSelected(int idx);
+    TEMPLATEPARSER_NO_EXPORT void clear();
     std::unique_ptr<CustomTemplatesMenuPrivate> const d;
 };
 }
-
