@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ TemplateParserEmailAddressRequesterBase::TemplateParserEmailAddressRequesterBase
 {
 }
 
-TemplateParserEmailAddressRequesterBase::~TemplateParserEmailAddressRequesterBase()
-{
-}
+TemplateParserEmailAddressRequesterBase::~TemplateParserEmailAddressRequesterBase() = default;
 
 QString TemplateParserEmailAddressRequesterBase::text() const
 {
@@ -23,7 +21,7 @@ QString TemplateParserEmailAddressRequesterBase::text() const
 
 void TemplateParserEmailAddressRequesterBase::setText(const QString &str)
 {
-    Q_UNUSED(str);
+    Q_UNUSED(str)
 }
 
 void TemplateParserEmailAddressRequesterBase::clear()
