@@ -4,13 +4,13 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef TEMPLATEPARSER_TEMPLATESCONFIGURATION_H
-#define TEMPLATEPARSER_TEMPLATESCONFIGURATION_H
+#pragma once
 
 #include "templateparser_export.h"
 #include "ui_templatesconfiguration_base.h"
 class QPlainTextEdit;
-namespace TemplateParser {
+namespace TemplateParser
+{
 class TemplatesConfigurationPrivate;
 /**
  * @brief The TemplatesConfiguration class
@@ -20,9 +20,8 @@ class TEMPLATEPARSER_EXPORT TemplatesConfiguration : public QWidget, Ui::Templat
     Q_OBJECT
 
 public:
-
     explicit TemplatesConfiguration(QWidget *parent = nullptr, const QString &name = QString());
-    ~TemplatesConfiguration();
+    ~TemplatesConfiguration() override;
 
     void loadFromGlobal();
     void saveToGlobal();
@@ -37,23 +36,19 @@ public:
     /**
      * Returns the template configuration identifier string for a given identity.
      */
-    static Q_REQUIRED_RESULT QString configIdString(uint id);
+    Q_REQUIRED_RESULT static QString configIdString(uint id);
 
 public Q_SLOTS:
     void slotInsertCommand(const QString &cmd, int adjustCursor = 0);
     void slotTextChanged();
 
-private Q_SLOTS:
-    void slotHelpLinkClicked(const QString &);
-
 Q_SIGNALS:
     void changed();
 
 private:
-    QPlainTextEdit *currentTextEdit() const;
-    QString strOrBlank(const QString &str);
-    TemplatesConfigurationPrivate *const d;
+    TEMPLATEPARSER_NO_EXPORT void slotHelpLinkClicked(const QString &);
+    Q_REQUIRED_RESULT TEMPLATEPARSER_NO_EXPORT QPlainTextEdit *currentTextEdit() const;
+    Q_REQUIRED_RESULT TEMPLATEPARSER_NO_EXPORT QString strOrBlank(const QString &str);
+    std::unique_ptr<TemplatesConfigurationPrivate> const d;
 };
 }
-
-#endif
