@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -13,6 +13,4 @@ TemplatesTextEdit::TemplatesTextEdit(QWidget *parent)
 {
 }
 
-TemplatesTextEdit::~TemplatesTextEdit()
-{
-}
+TemplatesTextEdit::~TemplatesTextEdit() = default;
