@@ -1,16 +1,16 @@
-/* SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef TEMPLATEPARSER_TEMPLATESTEXTEDIT_H
-#define TEMPLATEPARSER_TEMPLATESTEXTEDIT_H
+#pragma once
 
 #include "templateparser_export.h"
 
 #include <KPIMTextEdit/PlainTextEditorWidget>
 
-namespace TemplateParser {
+namespace TemplateParser
+{
 /**
  * @brief The TemplatesTextEdit class
  * @author Laurent Montel <montel@kde.org>
@@ -20,8 +20,6 @@ class TEMPLATEPARSER_EXPORT TemplatesTextEdit : public KPIMTextEdit::PlainTextEd
     Q_OBJECT
 public:
     explicit TemplatesTextEdit(QWidget *parent = nullptr);
-    ~TemplatesTextEdit();
+    ~TemplatesTextEdit() override;
 };
 }
-
-#endif
