@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,9 +38,7 @@ TemplatesTextEditor::TemplatesTextEditor(QWidget *parent)
     createHighlighter();
 }
 
-TemplatesTextEditor::~TemplatesTextEditor()
-{
-}
+TemplatesTextEditor::~TemplatesTextEditor() = default;
 
 void TemplatesTextEditor::updateHighLighter()
 {
