@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,8 +13,8 @@ namespace TemplateParser
 {
 namespace Util
 {
-Q_REQUIRED_RESULT QStringList keywords();
-Q_REQUIRED_RESULT QStringList keywordsWithArgs();
+Q_REQUIRED_RESULT TEMPLATEPARSER_TESTS_EXPORT QStringList keywords();
+Q_REQUIRED_RESULT TEMPLATEPARSER_TESTS_EXPORT QStringList keywordsWithArgs();
 Q_REQUIRED_RESULT TEMPLATEPARSER_TESTS_EXPORT QString removeSpaceAtBegin(const QString &selection);
 }
 }
