@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ CheckPhishingUrlJobTest::CheckPhishingUrlJobTest(QObject *parent)
 {
 }
 
-CheckPhishingUrlJobTest::~CheckPhishingUrlJobTest()
-{
-}
+CheckPhishingUrlJobTest::~CheckPhishingUrlJobTest() = default;
 
 void CheckPhishingUrlJobTest::shouldNotBeAbleToStartWithEmptyUrl()
 {
