@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -31,7 +31,7 @@ public:
 
     void save();
     void load();
-    int calculateBackModeTime() const;
+    Q_REQUIRED_RESULT int calculateBackModeTime() const;
     void startOffMode();
     void exitBackOffMode();
     void updateTimer(int seconds);
