@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,13 +24,12 @@ public:
     ~BackOffModeManager() override;
 
     static BackOffModeManager *self();
-    bool isInBackOffMode() const;
+    Q_REQUIRED_RESULT bool isInBackOffMode() const;
 
     void startOffMode();
 
-    int numberOfHttpFailed() const;
+    Q_REQUIRED_RESULT int numberOfHttpFailed() const;
 
-public Q_SLOTS:
     void slotTimerFinished();
 
 private:
