@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -33,7 +33,7 @@ public:
     void close();
     Q_REQUIRED_RESULT bool fileExists() const;
 
-    bool reload();
+    Q_REQUIRED_RESULT bool reload();
 
     Q_REQUIRED_RESULT bool isValid() const;
     Q_REQUIRED_RESULT quint16 getUint16(int offset) const;
