@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,11 @@
 #include "checkphishingurlgui.h"
 
 #include <QApplication>
-#include <QStandardPaths>
-#include <QLineEdit>
-#include <QPushButton>
-#include <QPlainTextEdit>
 #include <QLabel>
+#include <QLineEdit>
+#include <QPlainTextEdit>
+#include <QPushButton>
+#include <QStandardPaths>
 #include <QVBoxLayout>
 
 extern WEBENGINEVIEWER_EXPORT bool webengineview_useCompactJson;
@@ -20,15 +20,15 @@ CheckPhishingUrlGui::CheckPhishingUrlGui(QWidget *parent)
     : QWidget(parent)
 {
     webengineview_useCompactJson = false;
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
 
-    QHBoxLayout *checkUrlLayout = new QHBoxLayout;
+    auto checkUrlLayout = new QHBoxLayout;
     layout->addLayout(checkUrlLayout);
-    QLabel *lab = new QLabel(QStringLiteral("Url to Check:"), this);
+    auto lab = new QLabel(QStringLiteral("Url to Check:"), this);
     checkUrlLayout->addWidget(lab);
     mCheckUrlLineEdit = new QLineEdit(this);
     checkUrlLayout->addWidget(mCheckUrlLineEdit);
-    QPushButton *button = new QPushButton(QStringLiteral("Check"), this);
+    auto button = new QPushButton(QStringLiteral("Check"), this);
     checkUrlLayout->addWidget(button);
     connect(button, &QPushButton::clicked, this, &CheckPhishingUrlGui::slotCheckUrl);
     connect(mCheckUrlLineEdit, &QLineEdit::returnPressed, this, &CheckPhishingUrlGui::slotCheckUrl);
@@ -42,9 +42,7 @@ CheckPhishingUrlGui::CheckPhishingUrlGui(QWidget *parent)
     layout->addWidget(mJson);
 }
 
-CheckPhishingUrlGui::~CheckPhishingUrlGui()
-{
-}
+CheckPhishingUrlGui::~CheckPhishingUrlGui() = default;
 
 void CheckPhishingUrlGui::slotCheckUrl()
 {
@@ -54,7 +52,7 @@ void CheckPhishingUrlGui::slotCheckUrl()
     }
     mResult->clear();
 
-    WebEngineViewer::CheckPhishingUrlJob *job = new WebEngineViewer::CheckPhishingUrlJob(this);
+    auto job = new WebEngineViewer::CheckPhishingUrlJob(this);
     connect(job, &WebEngineViewer::CheckPhishingUrlJob::result, this, &CheckPhishingUrlGui::slotGetResult);
     connect(job, &WebEngineViewer::CheckPhishingUrlJob::debugJson, this, &CheckPhishingUrlGui::slotJSonDebug);
     job->setUrl(QUrl::fromUserInput(urlStr));
@@ -94,7 +92,7 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
-    CheckPhishingUrlGui *w = new CheckPhishingUrlGui;
+    auto w = new CheckPhishingUrlGui;
 
     w->show();
     app.exec();
