@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -28,9 +28,7 @@ ManageLocalDataBaseGui::ManageLocalDataBaseGui(QWidget *parent)
     layout->addWidget(button);
 }
 
-ManageLocalDataBaseGui::~ManageLocalDataBaseGui()
-{
-}
+ManageLocalDataBaseGui::~ManageLocalDataBaseGui() = default;
 
 void ManageLocalDataBaseGui::slotDownloadFullDatabase()
 {
