@@ -1,5 +1,5 @@
 /* SPDX-FileCopyrightText: 2010 Torgny Nyblom <nyblom@kde.org>
- * SPDX-FileCopyrightText: 2010-2022 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2010-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -84,7 +84,7 @@ FindBarBase::FindBarBase(QWidget *parent)
     connect(mSearch, &QLineEdit::textChanged, this, &FindBarBase::autoSearch);
     connect(mSearch, &QLineEdit::returnPressed, this, &FindBarBase::findNext);
 
-    mStatus = new QLabel;
+    mStatus = new QLabel(this);
     mStatus->setObjectName(QStringLiteral("status"));
     mStatus->setTextFormat(Qt::PlainText);
     QFontMetrics fm(mStatus->font());
