@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,7 +14,8 @@
 #include <QTextEdit>
 #include <QWebEngineSettings>
 
-template<typename Arg, typename R, typename C> struct InvokeWrapper {
+template<typename Arg, typename R, typename C>
+struct InvokeWrapper {
     R *receiver;
     void (C::*memberFunction)(Arg);
     void operator()(Arg result)
@@ -72,9 +73,7 @@ TestWebEngineScript::TestWebEngineScript(QWidget *parent)
     connect(page, &TestWebEngineScriptPage::showConsoleMessage, this, &TestWebEngineScript::slotShowConsoleMessage);
 }
 
-TestWebEngineScript::~TestWebEngineScript()
-{
-}
+TestWebEngineScript::~TestWebEngineScript() = default;
 
 void TestWebEngineScript::slotShowConsoleMessage(const QString &msg)
 {
@@ -100,7 +99,9 @@ void TestWebEngineScript::slotExecuteScript()
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     auto testWebEngine = new TestWebEngineScript;
     testWebEngine->show();
     const int ret = app.exec();
@@ -118,7 +119,7 @@ TestScriptWidget::TestScriptWidget(QWidget *parent)
     mScriptCombo = new QComboBox;
     vScriptLayout->addWidget(mScriptCombo);
     fillScriptCombo(mScriptCombo);
-    connect(mScriptCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, &TestScriptWidget::slotCurrentIndexChanged);
+    connect(mScriptCombo, &QComboBox::currentIndexChanged, this, &TestScriptWidget::slotCurrentIndexChanged);
 
     mScriptEdit = new QTextEdit;
     mScriptEdit->setAcceptRichText(false);
