@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -37,17 +37,13 @@ public:
     void keyReleaseEvent(QKeyEvent *e);
 
     void showAccessKeys();
+    void hideAccessKeys();
 
 Q_SIGNALS:
     void openUrl(const QUrl &url);
-public Q_SLOTS:
-    void hideAccessKeys();
-
-private Q_SLOTS:
-    void handleSearchAccessKey(const QVariant &res);
 
 private:
+    WEBENGINEVIEWER_NO_EXPORT void handleSearchAccessKey(const QVariant &res);
     std::unique_ptr<WebEngineAccessKeyPrivate> const d;
 };
 }
-
