@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -36,7 +36,7 @@ Q_SIGNALS:
     void exportToPdfSuccess();
 
 private:
-    void slotPdfPrintingFinished(const QString &filePath, bool success);
+    WEBENGINEVIEWER_NO_EXPORT void slotPdfPrintingFinished(const QString &filePath, bool success);
     QString mPdfPath;
     QWebEngineView *mWebEngineView = nullptr;
 };
