@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -21,9 +21,7 @@ SubmittedFormWarningWidget::SubmittedFormWarningWidget(QWidget *parent)
     setText(i18n("Submit form is not allowed in mailer. Please open url in a browser."));
 }
 
-SubmittedFormWarningWidget::~SubmittedFormWarningWidget()
-{
-}
+SubmittedFormWarningWidget::~SubmittedFormWarningWidget() = default;
 
 void SubmittedFormWarningWidget::showWarning()
 {
